/************************************************************************//**
 *
 * @file    c17f63_reg.h
 *
 * @brief   The definition of S1C17F63's register.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2018-2019. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Jun. 2018    1.00
 *              - First revision.
 *          - 01 Nov. 2018    1.10
 *              - Modify register definition.
 *          - 19 Jun. 2019    1.20
 *              - Modify register definition.
 *          - 11 Sep. 2019    1.30
 *              - Modify register definition.
 *
 ******************************************************************************/
#ifndef C17F63_REG_H__
#define C17F63_REG_H__

#include <c17_mcu_select.h>

#ifdef __cplusplus
extern "C" {
#endif


// Peripheral Register Header files
#include "reg/misc_reg.h"
#include "reg/pwg_reg.h"
#include "reg/clg_f63_reg.h"
#include "reg/itc_f63_reg.h"
#include "reg/wdt2_reg.h"
#include "reg/rtclp_f63_reg.h"
#include "reg/svd3_reg.h"
#include "reg/t16_reg.h"
#include "reg/flashc_reg.h"
#include "reg/eepromc_reg.h"
#include "reg/pport_f63_reg.h"
#include "reg/upmux_f63_reg.h"
#include "reg/uart3_reg.h"
#include "reg/spia_reg.h"
#include "reg/i2c_reg.h"
#include "reg/spislv_sel_reg.h"
#include "reg/t16b_reg.h"
#include "reg/smcif_reg.h"
#include "reg/snda_reg.h"
#include "reg/adc12a_reg.h"
#include "reg/tsrvr_reg.h"
#include "reg/epdc_reg.h"


// Peripheral Register Base Address
#define MISC_REG_BASE_ADDR       0x4000      ///< MISC Register Base Address.
#define PWG_REG_BASE_ADDR        0x4020      ///< PWG Register Base Address.
#define CLG_REG_BASE_ADDR        0x4040      ///< CLG Register Base Address.
#define ITC_REG_BASE_ADDR        0x4080      ///< ITC Register Base Address.
#define WDT2_REG_BASE_ADDR       0x40A0      ///< WDT2 Register Base Address.
#define SVD3_REG_BASE_ADDR       0x4100      ///< SVD3 Register Base Address.
#define T16_0_REG_BASE_ADDR      0x4160      ///< T16_0 Register Base Address.
#define T16_1_REG_BASE_ADDR      0x43A0      ///< T16_1 Register Base Address.
#define T16_2_REG_BASE_ADDR      0x5480      ///< T16_2 Register Base Address.
#define T16_3_REG_BASE_ADDR      0x5260      ///< T16_3 Register Base Address.
#define FLASHC_REG_BASE_ADDR     0x41B0      ///< FLASHC Register Base Address.
#define EEPROMC_REG_BASE_ADDR    0x41C0      ///< EEPROMC Register Base Address.
#define PPORT_REG_BASE_ADDR      0x4200      ///< PPORT Register Base Address.
#define UPMUX_REG_BASE_ADDR      0x4300      ///< UPMUX Register Base Address.
#define UART3_0_REG_BASE_ADDR    0x4380      ///< UART3_0 Register Base Address.
#define SPIA_0_REG_BASE_ADDR     0x43B0      ///< SPIA_0 Register Base Address.
#define SPIA_1_REG_BASE_ADDR     0x5270      ///< SPIA_1 Register Base Address.
#define I2C_0_REG_BASE_ADDR      0x43C0      ///< I2C_0 Register Base Address.
#define SPISLV_SEL_REG_BASE_ADDR 0x43E0      ///< SPISLV_SEL Register Base Address.
#define T16B_0_REG_BASE_ADDR     0x5000      ///< T16B_0 Register Base Address.
#define T16B_1_REG_BASE_ADDR     0x5040      ///< T16B_1 Register Base Address.
#define SMCIF_0_REG_BASE_ADDR    0x5220      ///< SMCIF_0 Register Base Address.
#define SNDA_REG_BASE_ADDR       0x5300      ///< SNDA Register Base Address.
#define ADC12A_0_REG_BASE_ADDR   0x54A2      ///< ADC12A_0 Register Base Address.
#define TSRVR_0_REG_BASE_ADDR    0x54C0      ///< TSRVR_0 Register Base Address.
#define EPDC_REG_BASE_ADDR       0x5500      ///< EPDC Register Base Address.
#define RTCLP_REG_BASE_ADDR      0x0000      ///< RTCLP Register Base Address.


// ----- C17F63 Registers -----

/// ----- MISC -----

/// MISC System Protect Register.
#define MSCPROT                 (*((volatile MSCPROT_REG *)(MISC_REG_BASE_ADDR + 0x00))).reg

/// MISC IRAM Size Register.
#define MSCIRAMSZ               (*((volatile MSCIRAMSZ_REG *)(MISC_REG_BASE_ADDR + 0x02))).reg

/// MISC Vector Table Address Low Register.
#define MSCTTBRL                (*((volatile MSCTTBRL_REG *)(MISC_REG_BASE_ADDR + 0x04))).reg

/// MISC Vector Table Address High Register.
#define MSCTTBRH                (*((volatile MSCTTBRH_REG *)(MISC_REG_BASE_ADDR + 0x06))).reg

/// MISC Vector Table Address Register.
#define MSCTTBR                 (*((volatile MSCTTBR_DWORD_REG *)(MISC_REG_BASE_ADDR + 0x04))).reg

/// MISC PSR Register.
#define MSCPSR                  (*((volatile MSCPSR_REG *)(MISC_REG_BASE_ADDR + 0x08))).reg

/// ----- PWG -----

/// PWG VD1 Regulator Control Register.
#define PWGVD1CTL               (*((volatile PWGVD1CTL_REG *)(PWG_REG_BASE_ADDR + 0x00))).reg

/// ----- CLG -----

/// CLG System Clock Control Register
#define CLGSCLK                 (*((volatile CLGSCLK_REG *)(CLG_REG_BASE_ADDR + 0x00))).reg

/// CLG Oscillation Control Register.
#define CLGOSC                  (*((volatile CLGOSC_REG *)(CLG_REG_BASE_ADDR + 0x02))).reg

/// CLG IOSC Control Register.
#define CLGIOSC                 (*((volatile CLGIOSC_REG *)(CLG_REG_BASE_ADDR + 0x04))).reg

/// CLG OSC1 Trimming Register.
#define CLGOSC1TRIM             (*((volatile CLGOSC1TRIM_REG *)(CLG_REG_BASE_ADDR + 0x06))).reg

/// CLG OSC3 Control Register.
#define CLGOSC3                 (*((volatile CLGOSC3_REG *)(CLG_REG_BASE_ADDR + 0x08))).reg

/// CLG Interrupt Flag Register.
#define CLGINTF                 (*((volatile CLGINTF_REG *)(CLG_REG_BASE_ADDR + 0x0C))).reg

/// CLG Interrupt Enable Register.
#define CLGINTE                 (*((volatile CLGINTE_REG *)(CLG_REG_BASE_ADDR + 0x0E))).reg

/// CLG FOUT Control Register 0.
#define CLGFOUT0                (*((volatile CLGFOUT0_REG *)(CLG_REG_BASE_ADDR + 0x10))).reg

/// CLG Oscillation Frequency Trimming Register .
#define CLGTRIM                 (*((volatile CLGTRIM_REG *)(CLG_REG_BASE_ADDR + 0x14))).reg


/// ----- ITC -----

/// ITC Interrupt Level Setup Register 0
#define ITCLV0                  (*((volatile ITCLV0_REG *)(ITC_REG_BASE_ADDR + 0x00))).reg

/// ITC Interrupt Level Setup Register 1
#define ITCLV1                  (*((volatile ITCLV1_REG *)(ITC_REG_BASE_ADDR + 0x02))).reg

/// ITC Interrupt Level Setup Register 2
#define ITCLV2                  (*((volatile ITCLV2_REG *)(ITC_REG_BASE_ADDR + 0x04))).reg

/// ITC Interrupt Level Setup Register 3
#define ITCLV3                  (*((volatile ITCLV3_REG *)(ITC_REG_BASE_ADDR + 0x06))).reg

/// ITC Interrupt Level Setup Register 4
#define ITCLV4                  (*((volatile ITCLV4_REG *)(ITC_REG_BASE_ADDR + 0x08))).reg

/// ITC Interrupt Level Setup Register 5
#define ITCLV5                  (*((volatile ITCLV5_REG *)(ITC_REG_BASE_ADDR + 0x0A))).reg

/// ITC Interrupt Level Setup Register 6
#define ITCLV6                  (*((volatile ITCLV6_REG *)(ITC_REG_BASE_ADDR + 0x0C))).reg

/// ITC Interrupt Level Setup Register 7
#define ITCLV7                  (*((volatile ITCLV7_REG *)(ITC_REG_BASE_ADDR + 0x0E))).reg

/// ITC Interrupt Level Setup Register 8
#define ITCLV8                  (*((volatile ITCLV8_REG *)(ITC_REG_BASE_ADDR + 0x10))).reg

/// ITC Interrupt Level Setup Register 9
#define ITCLV9                  (*((volatile ITCLV9_REG *)(ITC_REG_BASE_ADDR + 0x12))).reg

// Interrupt Level Registers.
#define ILVSVD                  (*((volatile ITCLV0_REG *)(ITC_REG_BASE_ADDR + 0x00))).byte_reg[0]       ///< Supply voltage detector interrupt.
#define ILVPPORT                (*((volatile ITCLV0_REG *)(ITC_REG_BASE_ADDR + 0x00))).byte_reg[1]       ///< Port interrupt.
#define ILVCLG                  (*((volatile ITCLV1_REG *)(ITC_REG_BASE_ADDR + 0x02))).byte_reg[1]       ///< Clock generator interrupt.
#define ILVRTCLP_0              (*((volatile ITCLV2_REG *)(ITC_REG_BASE_ADDR + 0x04))).byte_reg[0]       ///< Real-time clock interrupt.
#define ILVT16_0                (*((volatile ITCLV2_REG *)(ITC_REG_BASE_ADDR + 0x04))).byte_reg[1]       ///< 16-bit timer Ch.0 interrupt.
#define ILVUART_0               (*((volatile ITCLV3_REG *)(ITC_REG_BASE_ADDR + 0x06))).byte_reg[0]       ///< UART Ch.0 interrupt.
#define ILVT16_1                (*((volatile ITCLV3_REG *)(ITC_REG_BASE_ADDR + 0x06))).byte_reg[1]       ///< 16-bit timer Ch.1 interrupt.
#define ILVSPIA_0               (*((volatile ITCLV4_REG *)(ITC_REG_BASE_ADDR + 0x08))).byte_reg[0]       ///< Synchronous serial interface Ch.0 interrupt.
#define ILVI2C_0                (*((volatile ITCLV4_REG *)(ITC_REG_BASE_ADDR + 0x08))).byte_reg[1]       ///< I2C Ch.0 interrupt.
#define ILVT16B_0               (*((volatile ITCLV5_REG *)(ITC_REG_BASE_ADDR + 0x0A))).byte_reg[0]       ///< 16-bit PWM timer Ch.0 interrupt.
#define ILVT16B_1               (*((volatile ITCLV5_REG *)(ITC_REG_BASE_ADDR + 0x0A))).byte_reg[1]       ///< 16-bit PWM timer Ch.1 interrupt.
#define ILVSMC_0                (*((volatile ITCLV6_REG *)(ITC_REG_BASE_ADDR + 0x0C))).byte_reg[0]       ///< Smart card interface Ch.0 interrupt.
#define ILVSNDA_0               (*((volatile ITCLV6_REG *)(ITC_REG_BASE_ADDR + 0x0C))).byte_reg[1]       ///< Sound generator interrupt.
#define ILVT16_2                (*((volatile ITCLV7_REG *)(ITC_REG_BASE_ADDR + 0x0E))).byte_reg[0]       ///< 16-bit timer Ch.2 interrupt.
#define ILVADC12_0              (*((volatile ITCLV7_REG *)(ITC_REG_BASE_ADDR + 0x0E))).byte_reg[1]       ///< 12-bit A/D converter interrupt.
#define ILVEPDC                 (*((volatile ITCLV8_REG *)(ITC_REG_BASE_ADDR + 0x10))).byte_reg[0]       ///< EPD controller/driver interrupt.
#define ILVEPRC                 (*((volatile ITCLV8_REG *)(ITC_REG_BASE_ADDR + 0x10))).byte_reg[1]       ///< EEPROM controller interrupt.
#define ILVT16_3                (*((volatile ITCLV9_REG *)(ITC_REG_BASE_ADDR + 0x12))).byte_reg[0]       ///< 16-bit timer Ch.3 interrupt.
#define ILVSPIA_1               (*((volatile ITCLV9_REG *)(ITC_REG_BASE_ADDR + 0x12))).byte_reg[1]       ///< Synchronous serial interface Ch.1 interrupt.

/// ----- WDT2 -----

/// WDT2 Clock Control Register
#define WDTCLK                  (*((volatile WDTCLK_REG *)(WDT2_REG_BASE_ADDR + 0x00))).reg

/// WDT2 Control Register
#define WDTCTL                  (*((volatile WDTCTL_REG *)(WDT2_REG_BASE_ADDR + 0x02))).reg

/// WDT2 Counter Compare Match Register.
#define WDTCMP                  (*((volatile WDTCMP_REG *)(WDT2_REG_BASE_ADDR + 0x04))).reg

/// ----  SVD3 ----

/// SVD3 Clock Control Register
#define SVDCLK                  (*((volatile SVDCLK_REG *)(SVD3_REG_BASE_ADDR + 0x00))).reg

/// SVD3 Control Register
#define SVDCTL                  (*((volatile SVDCTL_REG *)(SVD3_REG_BASE_ADDR + 0x02))).reg

/// SVD3 Status and Interrupt Flag Register
#define SVDINTF                 (*((volatile SVDINTF_REG *)(SVD3_REG_BASE_ADDR + 0x04))).reg

/// SVD3 Interrupt Enable Register
#define SVDINTE                 (*((volatile SVDINTE_REG *)(SVD3_REG_BASE_ADDR + 0x06))).reg

/// ----- T16 -----

/// T16 Ch.0 Clock Control Register
#define T16_0CLK                (*((volatile T16_NCLK_REG *)(T16_0_REG_BASE_ADDR + 0x00))).reg

/// T16 Ch.0 Mode Register
#define T16_0MOD                (*((volatile T16_NMOD_REG *)(T16_0_REG_BASE_ADDR + 0x02))).reg

/// T16 Ch.0 Control Register
#define T16_0CTL                (*((volatile T16_NCTL_REG *)(T16_0_REG_BASE_ADDR + 0x04))).reg

/// T16 Ch.0 Reload Data Register
#define T16_0TR                 (*((volatile T16_NTR_REG *)(T16_0_REG_BASE_ADDR + 0x06))).reg

/// T16 Ch.0 Counter Data Register
#define T16_0TC                 (*((volatile T16_NTC_REG *)(T16_0_REG_BASE_ADDR + 0x08))).reg

/// T16 Ch.0 Interrupt Flag Register
#define T16_0INTF               (*((volatile T16_NINTF_REG *)(T16_0_REG_BASE_ADDR + 0x0A))).reg

/// T16 Ch.0 Interrupt Enable Register
#define T16_0INTE               (*((volatile T16_NINTE_REG *)(T16_0_REG_BASE_ADDR + 0x0C))).reg

/// T16 Ch.1 Clock Control Register
#define T16_1CLK                (*((volatile T16_NCLK_REG *)(T16_1_REG_BASE_ADDR + 0x00))).reg

/// T16 Ch.1 Mode Register
#define T16_1MOD                (*((volatile T16_NMOD_REG *)(T16_1_REG_BASE_ADDR + 0x02))).reg

/// T16 Ch.1 Control Register
#define T16_1CTL                (*((volatile T16_NCTL_REG *)(T16_1_REG_BASE_ADDR + 0x04))).reg

/// T16 Ch.1 Reload Data Register
#define T16_1TR                 (*((volatile T16_NTR_REG *)(T16_1_REG_BASE_ADDR + 0x06))).reg

/// T16 Ch.1 Counter Data Register
#define T16_1TC                 (*((volatile T16_NTC_REG *)(T16_1_REG_BASE_ADDR + 0x08))).reg

/// T16 Ch.1 Interrupt Flag Register
#define T16_1INTF               (*((volatile T16_NINTF_REG *)(T16_1_REG_BASE_ADDR + 0x0A))).reg

/// T16 Ch.1 Interrupt Enable Register
#define T16_1INTE               (*((volatile T16_NINTE_REG *)(T16_1_REG_BASE_ADDR + 0x0C))).reg

/// T16 Ch.2 Clock Control Register
#define T16_2CLK                (*((volatile T16_NCLK_REG *)(T16_2_REG_BASE_ADDR + 0x00))).reg

/// T16 Ch.2 Mode Register
#define T16_2MOD                (*((volatile T16_NMOD_REG *)(T16_2_REG_BASE_ADDR + 0x02))).reg

/// T16 Ch.2 Control Register
#define T16_2CTL                (*((volatile T16_NCTL_REG *)(T16_2_REG_BASE_ADDR + 0x04))).reg

/// T16 Ch.2 Reload Data Register
#define T16_2TR                 (*((volatile T16_NTR_REG *)(T16_2_REG_BASE_ADDR + 0x06))).reg

/// T16 Ch.2 Counter Data Register
#define T16_2TC                 (*((volatile T16_NTC_REG *)(T16_2_REG_BASE_ADDR + 0x08))).reg

/// T16 Ch.2 Interrupt Flag Register
#define T16_2INTF               (*((volatile T16_NINTF_REG *)(T16_2_REG_BASE_ADDR + 0x0A))).reg

/// T16 Ch.2 Interrupt Enable Register
#define T16_2INTE               (*((volatile T16_NINTE_REG *)(T16_2_REG_BASE_ADDR + 0x0C))).reg

/// T16 Ch.3 Clock Control Register
#define T16_3CLK                (*((volatile T16_NCLK_REG *)(T16_3_REG_BASE_ADDR + 0x00))).reg

/// T16 Ch.3 Mode Register
#define T16_3MOD                (*((volatile T16_NMOD_REG *)(T16_3_REG_BASE_ADDR + 0x02))).reg

/// T16 Ch.3 Control Register
#define T16_3CTL                (*((volatile T16_NCTL_REG *)(T16_3_REG_BASE_ADDR + 0x04))).reg

/// T16 Ch.3 Reload Data Register
#define T16_3TR                 (*((volatile T16_NTR_REG *)(T16_3_REG_BASE_ADDR + 0x06))).reg

/// T16 Ch.3 Counter Data Register
#define T16_3TC                 (*((volatile T16_NTC_REG *)(T16_3_REG_BASE_ADDR + 0x08))).reg

/// T16 Ch.3 Interrupt Flag Register
#define T16_3INTF               (*((volatile T16_NINTF_REG *)(T16_3_REG_BASE_ADDR + 0x0A))).reg

/// T16 Ch.3 Interrupt Enable Register
#define T16_3INTE               (*((volatile T16_NINTE_REG *)(T16_3_REG_BASE_ADDR + 0x0C))).reg

/// ----- FLASHC -----

/// FLASHC Flash Read Cycle Register
#define FLASHCWAIT              (*((volatile FLASHCWAIT_REG *)(FLASHC_REG_BASE_ADDR + 0x00))).reg

/// ----- EEPROMC -----

/// EEPROMC Control Register 0
#define EPRCCTL0                (*((volatile EPRCCTL0_REG *)(EEPROMC_REG_BASE_ADDR + 0x00))).reg

/// EEPROMC Control Register 1
#define EPRCCTL1                (*((volatile EPRCCTL1_REG *)(EEPROMC_REG_BASE_ADDR + 0x02))).reg

/// EEPROMC Address Register
#define EPRCADR                 (*((volatile EPRCADR_REG *)(EEPROMC_REG_BASE_ADDR + 0x04))).reg

/// EEPROMC Write Data Register
#define EPRCWDAT                (*((volatile EPRCWDAT_REG *)(EEPROMC_REG_BASE_ADDR + 0x06))).reg

/// EEPROMC Interrupt Flag Register
#define EPRCINTF                (*((volatile EPRCINTF_REG *)(EEPROMC_REG_BASE_ADDR + 0x08))).reg

/// EEPROMC Interrupt Enable Register
#define EPRCINTE                (*((volatile EPRCINTE_REG *)(EEPROMC_REG_BASE_ADDR + 0x0A))).reg

/// ----- PPORT -----

/// P0 Port Data Register
#define P0DAT                   (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).reg

/// P0 Port Enable Register
#define P0IOEN                  (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).reg

/// P0 Port Pull-up/down Control Register
#define P0RCTL                  (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).reg

/// P0 Port Interrupt Flag Register
#define P0INTF                  (*((volatile P0INTF_REG *)(PPORT_REG_BASE_ADDR + 0x06))).reg

/// P0 Port Interrupt Control Register
#define P0INTCTL                (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).reg

/// P0 Port Chattering Filter Enable Register
#define P0CHATEN                (*((volatile P0CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x0A))).reg

/// P0 Port Mode Select Register
#define P0MODSEL                (*((volatile P0MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0C))).reg

/// P0 Port Function Select Register
#define P0FNCSEL                (*((volatile P0FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0E))).reg

/// P1 Port Data Register
#define P1DAT                   (*((volatile P1DAT_REG *)(PPORT_REG_BASE_ADDR + 0x10))).reg

/// P1 Port Enable Register
#define P1IOEN                  (*((volatile P1IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x12))).reg

/// P1 Port Pull-up/down Control Register
#define P1RCTL                  (*((volatile P1RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x14))).reg

/// P1 Port Interrupt Flag Register
#define P1INTF                  (*((volatile P1INTF_REG *)(PPORT_REG_BASE_ADDR + 0x16))).reg

/// P1 Port Interrupt Control Register
#define P1INTCTL                (*((volatile P1INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x18))).reg

/// P1 Port Chattering Filter Enable Register
#define P1CHATEN                (*((volatile P1CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x1A))).reg

/// P1 Port Mode Select Register
#define P1MODSEL                (*((volatile P1MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x1C))).reg

/// P1 Port Function Select Register
#define P1FNCSEL                (*((volatile P1FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x1E))).reg

/// Pd Port Data Register
#define PDDAT                   (*((volatile PDDAT_REG *)(PPORT_REG_BASE_ADDR + 0xD0))).reg

/// Pd Port Enable Register
#define PDIOEN                  (*((volatile PDIOEN_REG *)(PPORT_REG_BASE_ADDR + 0xD2))).reg

/// Pd Port Pull-up/down Control Register
#define PDRCTL                  (*((volatile PDRCTL_REG *)(PPORT_REG_BASE_ADDR + 0xD4))).reg

/// Pd Port Mode Select Register
#define PDMODSEL                (*((volatile PDMODSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDC))).reg

/// Pd Port Function Select Register
#define PDFNCSEL                (*((volatile PDFNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDE))).reg

/// P Port Clock Control Register
#define PCLK                    (*((volatile PCLK_REG *)(PPORT_REG_BASE_ADDR + 0xE0))).reg

/// P Port Interrupt Flag Group Register
#define PINTFGRP                (*((volatile PINTFGRP_REG *)(PPORT_REG_BASE_ADDR + 0xE2))).reg

/// ----- UPMUX ----

/// P00-01 Universal Port Multiplexer Setting Register
#define P0UPMUX0                (*((volatile P0UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x00))).reg

/// P02-03 Universal Port Multiplexer Setting Register
#define P0UPMUX1                (*((volatile P0UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x02))).reg

/// P04-05 Universal Port Multiplexer Setting Register
#define P0UPMUX2                (*((volatile P0UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x04))).reg

/// P06-07 Universal Port Multiplexer Setting Register
#define P0UPMUX3                (*((volatile P0UPMUX3_REG *)(UPMUX_REG_BASE_ADDR + 0x06))).reg

/// P10-11 Universal Port Multiplexer Setting Register
#define P1UPMUX0                (*((volatile P1UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x08))).reg

/// P12-13 Universal Port Multiplexer Setting Register
#define P1UPMUX1                (*((volatile P1UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x0A))).reg

/// P14-15 Universal Port Multiplexer Setting Register
#define P1UPMUX2                (*((volatile P1UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x0C))).reg

/// ---- UART3 -----

/// UART3 Ch.0 Clock Control Register
#define UA0CLK                  (*((volatile UANCLK_REG *)(UART3_0_REG_BASE_ADDR + 0x00))).reg

/// UART3 Ch.0 Mode Register
#define UA0MOD                  (*((volatile UANMOD_REG *)(UART3_0_REG_BASE_ADDR + 0x02))).reg

/// UART3 Ch.0 Baud-Rate Register
#define UA0BR                   (*((volatile UANBR_REG *)(UART3_0_REG_BASE_ADDR + 0x04))).reg

/// UART3 Ch.0 Control Register
#define UA0CTL                  (*((volatile UANCTL_REG *)(UART3_0_REG_BASE_ADDR + 0x06))).reg

/// UART3 Ch.0 Transmit Data Register
#define UA0TXD                  (*((volatile UANTXD_REG *)(UART3_0_REG_BASE_ADDR + 0x08))).reg

/// UART3 Ch.0 Receive Data Register
#define UA0RXD                  (*((volatile UANRXD_REG *)(UART3_0_REG_BASE_ADDR + 0x0A))).reg

/// UART3 Ch.0 Status and Interrupt Flag Register
#define UA0INTF                 (*((volatile UANINTF_REG *)(UART3_0_REG_BASE_ADDR + 0x0C))).reg

/// UART3 Ch.0 Interrupt Enable Register
#define UA0INTE                 (*((volatile UANINTE_REG *)(UART3_0_REG_BASE_ADDR + 0x0E))).reg

/// UART3 Ch.0 Carrier Waveform Register
#define UA0CAWF                 (*((volatile UANCAWF_REG *)(UART3_0_REG_BASE_ADDR + 0x10))).reg

/// ----- SPIA ----

/// SPIA Ch.0 Mode Register
#define SPI0MOD                 (*((volatile SPINMOD_REG *)(SPIA_0_REG_BASE_ADDR + 0x00))).reg

/// SPIA Ch.0 Control Register
#define SPI0CTL                 (*((volatile SPINCTL_REG *)(SPIA_0_REG_BASE_ADDR + 0x02))).reg

/// SPIA Ch.0 Transmit Data Register
#define SPI0TXD                 (*((volatile SPINTXD_REG *)(SPIA_0_REG_BASE_ADDR + 0x04))).reg

/// SPIA Ch.0 Receive Data Register
#define SPI0RXD                 (*((volatile SPINRXD_REG *)(SPIA_0_REG_BASE_ADDR + 0x06))).reg

/// SPIA Ch.0 Interrupt Flag Register
#define SPI0INTF                (*((volatile SPININTF_REG *)(SPIA_0_REG_BASE_ADDR + 0x08))).reg

/// SPIA Ch.0 Interrupt Enable Register
#define SPI0INTE                (*((volatile SPININTE_REG *)(SPIA_0_REG_BASE_ADDR + 0x0A))).reg

/// SPIA Ch.1 Mode Register
#define SPI1MOD                 (*((volatile SPINMOD_REG *)(SPIA_1_REG_BASE_ADDR + 0x00))).reg

/// SPIA Ch.1 Control Register
#define SPI1CTL                 (*((volatile SPINCTL_REG *)(SPIA_1_REG_BASE_ADDR + 0x02))).reg

/// SPIA Ch.1 Transmit Data Register
#define SPI1TXD                 (*((volatile SPINTXD_REG *)(SPIA_1_REG_BASE_ADDR + 0x04))).reg

/// SPIA Ch.1 Receive Data Register
#define SPI1RXD                 (*((volatile SPINRXD_REG *)(SPIA_1_REG_BASE_ADDR + 0x06))).reg

/// SPIA Ch.1 Interrupt Flag Register
#define SPI1INTF                (*((volatile SPININTF_REG *)(SPIA_1_REG_BASE_ADDR + 0x08))).reg

/// SPIA Ch.1 Interrupt Enable Register
#define SPI1INTE                (*((volatile SPININTE_REG *)(SPIA_1_REG_BASE_ADDR + 0x0A))).reg

/// ----- I2C -----

/// I2C Ch.0 Clock Control Register
#define I2C0CLK                 (*((volatile I2CNCLK_REG *)(I2C_0_REG_BASE_ADDR + 0x00))).reg

/// I2C Ch.0 Mode Register
#define I2C0MOD                 (*((volatile I2CNMOD_REG *)(I2C_0_REG_BASE_ADDR + 0x02))).reg

/// I2C Ch.0 Baud-Rate Register
#define I2C0BR                  (*((volatile I2CNBR_REG *)(I2C_0_REG_BASE_ADDR + 0x04))).reg

/// I2C Ch.0 Own Address Register
#define I2C0OADR                (*((volatile I2CNOADR_REG *)(I2C_0_REG_BASE_ADDR + 0x08))).reg

/// I2C Ch.0 Control Register
#define I2C0CTL                 (*((volatile I2CNCTL_REG *)(I2C_0_REG_BASE_ADDR + 0x0A))).reg

/// I2C Ch.0 Transmit Data Register
#define I2C0TXD                 (*((volatile I2CNTXD_REG *)(I2C_0_REG_BASE_ADDR + 0x0C))).reg

/// I2C Ch.0 Receive Data Register
#define I2C0RXD                 (*((volatile I2CNRXD_REG *)(I2C_0_REG_BASE_ADDR + 0x0E))).reg

/// I2C Ch.0 Status and Interrupt Flag Register
#define I2C0INTF                (*((volatile I2CNINTF_REG *)(I2C_0_REG_BASE_ADDR + 0x10))).reg

/// I2C Ch.0 Interrupt Enable Register
#define I2C0INTE                (*((volatile I2CNINTE_REG *)(I2C_0_REG_BASE_ADDR + 0x12))).reg

/// ----- SPISLV_SEL ------

/// SPI Slave Select Register
#define SPISLVSEL               (*((volatile SPISLVSEL_REG *)(SPISLV_SEL_REG_BASE_ADDR + 0x00))).reg

/// ----- T16B ------

/// T16B Ch.0 Clock Control Register
#define T16B0CLK                (*((volatile T16BNCLK_REG *)(T16B_0_REG_BASE_ADDR + 0x00))).reg

/// T16B Ch.0 Counter Control Register.
#define T16B0CTL                (*((volatile T16BNCTL_REG *)(T16B_0_REG_BASE_ADDR + 0x02))).reg

/// T16B Ch.0 Max Counter Data Register
#define T16B0MC                 (*((volatile T16BNMC_REG *)(T16B_0_REG_BASE_ADDR + 0x04))).reg

/// T16B Ch.0 Timer Counter Data Register.
#define T16B0TC                 (*((volatile T16BNTC_REG *)(T16B_0_REG_BASE_ADDR + 0x06))).reg

/// T16B Ch.0 Counter Status Register
#define T16B0CS                 (*((volatile T16BNCS_REG *)(T16B_0_REG_BASE_ADDR + 0x08))).reg

/// T16B Ch.0 Interrupt Flag Register.
#define T16B0INTF               (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).reg

/// T16B Ch.0 Interrupt Enable Register.
#define T16B0INTE               (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).reg

/// T16B Ch.0 Comparator/Capture 0 Control Register.
#define T16B0CCCTL0             (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x10))).reg

/// T16B Ch.0 Compare/Capture 0 Data Register.
#define T16B0CCR0               (*((volatile T16BNCCRM_REG *)(T16B_0_REG_BASE_ADDR + 0x12))).reg

/// T16B Ch.0 Comparator/Capture 1 Control Register.
#define T16B0CCCTL1             (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x18))).reg

/// T16B Ch.0 Compare/Capture 1 Data Register.
#define T16B0CCR1               (*((volatile T16BNCCRM_REG *)(T16B_0_REG_BASE_ADDR + 0x1A))).reg

/// T16B Ch.1 Clock Control Register
#define T16B1CLK                (*((volatile T16BNCLK_REG *)(T16B_1_REG_BASE_ADDR + 0x00))).reg

/// T16B Ch.1 Counter Control Register.
#define T16B1CTL                (*((volatile T16BNCTL_REG *)(T16B_1_REG_BASE_ADDR + 0x02))).reg

/// T16B Ch.1 Max Counter Data Register
#define T16B1MC                 (*((volatile T16BNMC_REG *)(T16B_1_REG_BASE_ADDR + 0x04))).reg

/// T16B Ch.1 Timer Counter Data Register.
#define T16B1TC                 (*((volatile T16BNTC_REG *)(T16B_1_REG_BASE_ADDR + 0x06))).reg

/// T16B Ch.1 Counter Status Register
#define T16B1CS                 (*((volatile T16BNCS_REG *)(T16B_1_REG_BASE_ADDR + 0x08))).reg

/// T16B Ch.1 Interrupt Flag Register.
#define T16B1INTF               (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).reg

/// T16B Ch.1 Interrupt Enable Register.
#define T16B1INTE               (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).reg

/// T16B Ch.1 Comparator/Capture 0 Control Register.
#define T16B1CCCTL0             (*((volatile T16B1CCCTLN_REG *)(T16B_1_REG_BASE_ADDR + 0x10))).reg

/// T16B Ch.1 Compare/Capture 0 Data Register.
#define T16B1CCR0               (*((volatile T16B1CCRN_REG *)(T16B_1_REG_BASE_ADDR + 0x12))).reg

/// T16B Ch.1 Comparator/Capture 1 Control Register.
#define T16B1CCCTL1             (*((volatile T16B1CCCTLN_REG *)(T16B_1_REG_BASE_ADDR + 0x18))).reg

/// T16B Ch.1 Compare/Capture 1 Data Register.
#define T16B1CCR1               (*((volatile T16B1CCRN_REG *)(T16B_1_REG_BASE_ADDR + 0x1A))).reg

/// ----- SMCIF ------

/// SMCIF Ch.0 Clock Control Register
#define SMC0CLK                 (*((volatile SMCNCLK_REG *)(SMCIF_0_REG_BASE_ADDR + 0x00))).reg

/// SMCIF Ch.0 Mode Register
#define SMC0MOD                 (*((volatile SMCNMOD_REG *)(SMCIF_0_REG_BASE_ADDR + 0x02))).reg

/// SMCIF Ch.0 Baud Rate Register
#define SMC0BR                  (*((volatile SMCNBR_REG *)(SMCIF_0_REG_BASE_ADDR + 0x04))).reg

/// SMCIF Ch.0 Control Register
#define SMC0CTL                 (*((volatile SMCNCTL_REG *)(SMCIF_0_REG_BASE_ADDR + 0x06))).reg

/// SMCIF Ch.0 Transmit Data Register
#define SMC0TXD                 (*((volatile SMCNTXD_REG *)(SMCIF_0_REG_BASE_ADDR + 0x08))).reg

/// SMCIF Ch.0 Receive Data Register
#define SMC0RXD                 (*((volatile SMCNRXD_REG *)(SMCIF_0_REG_BASE_ADDR + 0x0A))).reg

/// SMCIF Ch.0 Wait Time Compare Data Register 0
#define SMC0WTC0                (*((volatile SMCNWTC0_REG *)(SMCIF_0_REG_BASE_ADDR + 0x0C))).reg

/// SMCIF Ch.0 Wait Time Compare Data Register 1
#define SMC0WTC1                (*((volatile SMCNWTC1_REG *)(SMCIF_0_REG_BASE_ADDR + 0x0E))).reg

/// SMCIF Ch.0 Wait Time Compare Data Register
#define SMC0WTC                 (*((volatile SMCNWTC_DWORD_REG *)(SMCIF_0_REG_BASE_ADDR + 0x0C))).reg

/// SMCIF Ch.0 Guard Time Compare Data Register
#define SMC0GTC                 (*((volatile SMCNGTC_REG *)(SMCIF_0_REG_BASE_ADDR + 0x10))).reg

/// SMCIF Ch.0 Status and Interrupt Flag Register
#define SMC0INTF                (*((volatile SMCNINTF_REG *)(SMCIF_0_REG_BASE_ADDR + 0x12))).reg

/// SMCIF Ch.0 Interrupt Enable Register
#define SMC0INTE                (*((volatile SMCNINTE_REG *)(SMCIF_0_REG_BASE_ADDR + 0x14))).reg

/// SMCIF Ch.0 Etu Counter Data Register 0
#define SMC0ETU0                (*((volatile SMCNETU0_REG *)(SMCIF_0_REG_BASE_ADDR + 0x16))).reg

/// SMCIF Ch.0 Etu Counter Data Register 1
#define SMC0ETU1                (*((volatile SMCNETU1_REG *)(SMCIF_0_REG_BASE_ADDR + 0x18))).reg

/// SMCIF Ch.0 Etu Counter Data Register
#define SMC0ETU                 (*((volatile SMCNETU_DWORD_REG *)(SMCIF_0_REG_BASE_ADDR + 0x16))).reg

/// ----- SNDA ------

/// SNDA Clock Control Register
#define SNDCLK                  (*((volatile SNDCLK_REG *)(SNDA_REG_BASE_ADDR + 0x00))).reg

/// SNDA Select Register
#define SNDSEL                  (*((volatile SNDSEL_REG *)(SNDA_REG_BASE_ADDR + 0x02))).reg

/// SNDA Control Register
#define SNDCTL                  (*((volatile SNDCTL_REG *)(SNDA_REG_BASE_ADDR + 0x04))).reg

/// SNDA Data Register
#define SNDDAT                  (*((volatile SNDDAT_REG *)(SNDA_REG_BASE_ADDR + 0x06))).reg

/// SNDA Interrupt Flag Register
#define SNDINTF                 (*((volatile SNDINTF_REG *)(SNDA_REG_BASE_ADDR + 0x08))).reg

/// SNDA Interrupt Enable Register
#define SNDINTE                 (*((volatile SNDINTE_REG *)(SNDA_REG_BASE_ADDR + 0x0A))).reg

/// ----- ADC12A ------

/// ADC12A Ch.0 Control Register
#define ADC12_0CTL              (*((volatile ADC12_NCTL_REG *)(ADC12A_0_REG_BASE_ADDR + 0x00))).reg

/// ADC12A Ch.0 Trigger/Analog Input Select Register
#define ADC12_0TRG              (*((volatile ADC12_NTRG_REG *)(ADC12A_0_REG_BASE_ADDR + 0x02))).reg

/// ADC12A Ch.0 Configuration Register
#define ADC12_0CFG              (*((volatile ADC12_NCFG_REG *)(ADC12A_0_REG_BASE_ADDR + 0x04))).reg

/// ADC12A Ch.0 Interrupt Flag Register
#define ADC12_0INTF             (*((volatile ADC12_NINTF_REG *)(ADC12A_0_REG_BASE_ADDR + 0x06))).reg

/// ADC12A Ch.0 Interrupt Enable Register
#define ADC12_0INTE             (*((volatile ADC12_NINTE_REG *)(ADC12A_0_REG_BASE_ADDR + 0x08))).reg

/// ADC12A Ch.0 Result Register 0
#define ADC12_0AD0D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x0A))).reg

/// ADC12A Ch.0 Result Register 1
#define ADC12_0AD1D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x0C))).reg

/// ADC12A Ch.0 Result Register 2
#define ADC12_0AD2D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x0E))).reg

/// ADC12A Ch.0 Result Register 3
#define ADC12_0AD3D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x10))).reg

/// ADC12A Ch.0 Result Register 4
#define ADC12_0AD4D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x12))).reg

/// ADC12A Ch.0 Result Register 5
#define ADC12_0AD5D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x14))).reg

/// ADC12A Ch.0 Result Register 6
#define ADC12_0AD6D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x16))).reg

/// ADC12A Ch.0 Result Register 7
#define ADC12_0AD7D             (*((volatile ADC12_NADMD_REG *)(ADC12A_0_REG_BASE_ADDR + 0x18))).reg

/// ----- TSRVR ------

/// TSRVR Ch.0 Temperature Sensor Control Register
#define TSRVR0TCTL              (*((volatile TSRVRNTCTL_REG *)(TSRVR_0_REG_BASE_ADDR + 0x00))).reg

/// TSRVR Ch.0 Reference Voltage Generator Control Register
#define TSRVR0VCTL              (*((volatile TSRVRNVCTL_REG *)(TSRVR_0_REG_BASE_ADDR + 0x02))).reg


/// ----- EPDC -----

/// EPDC Timing Clock Control Register.
#define EPDTIMCLK               (*((volatile EPDTIMCLK_REG *)(EPDC_REG_BASE_ADDR + 0x00))).reg

/// EPDC Doubler Clock Control Register.
#define EPDDBLCLK               (*((volatile EPDDBLCLK_REG *)(EPDC_REG_BASE_ADDR + 0x02))).reg

/// EPDC Booster Clock Control Register.
#define EPDBSTCLK               (*((volatile EPDBSTCLK_REG *)(EPDC_REG_BASE_ADDR + 0x04))).reg

/// EPDC Control Register.
#define EPDCTL                  (*((volatile EPDCTL_REG *)(EPDC_REG_BASE_ADDR + 0x06))).reg

/// EPDC power supply Control Register 0.
#define EPDPWR0                 (*((volatile EPDPWR0_REG *)(EPDC_REG_BASE_ADDR + 0x08))).reg

/// EPDC power supply Control Register 1.
#define EPDPWR1                 (*((volatile EPDPWR1_REG *)(EPDC_REG_BASE_ADDR + 0x0A))).reg

/// EPD Display Control Register.
#define EPDDSP                  (*((volatile EPDDSP_REG *)(EPDC_REG_BASE_ADDR + 0x0C))).reg

/// EPDC Pin Assignment Select Register.
#define EPDPOS                  (*((volatile EPDPOS_REG *)(EPDC_REG_BASE_ADDR + 0x0E))).reg

/// EPDC interrupt flag status Register.
#define EPDINTF                 (*((volatile EPDINTF_REG *)(EPDC_REG_BASE_ADDR + 0x10))).reg

/// EPDC interrupt flag enable Register.
#define EPDINTE                 (*((volatile EPDINTE_REG *)(EPDC_REG_BASE_ADDR + 0x12))).reg

/// EPDC Top/Back Plane Data Register.
#define EPDTPBP                 (*((volatile EPDTPBP_REG *)(EPDC_REG_BASE_ADDR + 0x20))).reg

/// EPD Segment Data Register 0.
#define EPDSEG0                 (*((volatile EPDSEG0_REG *)(EPDC_REG_BASE_ADDR + 0x22))).reg

/// EPD Segment Data Register 1.
#define EPDSEG1                 (*((volatile EPDSEG1_REG *)(EPDC_REG_BASE_ADDR + 0x24))).reg

/// EPD Segment Data Register 2.
#define EPDSEG2                 (*((volatile EPDSEG2_REG *)(EPDC_REG_BASE_ADDR + 0x26))).reg

/// EPD Top/Back Plane Enable Register.
#define EPDTPBPEN               (*((volatile EPDTPBPEN_REG *)(EPDC_REG_BASE_ADDR + 0x30))).reg

/// EPD Segment Enable Register 0.
#define EPDSEGEN0               (*((volatile EPDSEGEN0_REG *)(EPDC_REG_BASE_ADDR + 0x32))).reg

/// EPD Segment Enable Register 1.
#define EPDSEGEN1               (*((volatile EPDSEGEN1_REG *)(EPDC_REG_BASE_ADDR + 0x34))).reg

/// EPD Segment Enable Register 2.
#define EPDSEGEN2               (*((volatile EPDSEGEN2_REG *)(EPDC_REG_BASE_ADDR + 0x36))).reg

/// EPD Waveform Timing Set Registers 0.
#define EPDWAVE0                (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x40))).reg

/// EPD Waveform Timing Set Registers 1.
#define EPDWAVE1                (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x42))).reg

/// EPD Waveform Timing Set Registers 2.
#define EPDWAVE2                (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x44))).reg

/// EPD Waveform Timing Set Registers 3.
#define EPDWAVE3                (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x46))).reg

/// EPD Waveform Timing Set Registers 4.
#define EPDWAVE4                (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x48))).reg

/// EPD Waveform Timing Set Registers 5.
#define EPDWAVE5                (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x4A))).reg

/// EPD Waveform Timing Set Registers 6.
#define EPDWAVE6                (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x4C))).reg

/// EPD Waveform Timing Set Registers 7.
#define EPDWAVE7                (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x4E))).reg

/// EPD Waveform Timing Set Registers 8.
#define EPDWAVE8                (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x50))).reg

/// EPD Waveform Timing Set Registers 9.
#define EPDWAVE9                (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x52))).reg

/// EPD Waveform Timing Set Registers 10.
#define EPDWAVE10               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x54))).reg

/// EPD Waveform Timing Set Registers 11.
#define EPDWAVE11               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x56))).reg

/// EPD Waveform Timing Set Registers 12.
#define EPDWAVE12               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x58))).reg

/// EPD Waveform Timing Set Registers 13.
#define EPDWAVE13               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x5A))).reg

/// EPD Waveform Timing Set Registers 14.
#define EPDWAVE14               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x5C))).reg

/// EPD Waveform Timing Set Registers 15.
#define EPDWAVE15               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x5E))).reg

/// EPD Waveform Timing Set Registers 16.
#define EPDWAVE16               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x60))).reg

/// EPD Waveform Timing Set Registers 17.
#define EPDWAVE17               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x62))).reg

/// EPD Waveform Timing Set Registers 18.
#define EPDWAVE18               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x64))).reg

/// EPD Waveform Timing Set Registers 19.
#define EPDWAVE19               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x66))).reg

/// EPD Waveform Timing Set Registers 20.
#define EPDWAVE20               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x68))).reg

/// EPD Waveform Timing Set Registers 21.
#define EPDWAVE21               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x6A))).reg

/// EPD Waveform Timing Set Registers 22.
#define EPDWAVE22               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x6C))).reg

/// EPD Waveform Timing Set Registers 23.
#define EPDWAVE23               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x6E))).reg

/// EPD Waveform Timing Set Registers 24.
#define EPDWAVE24               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x70))).reg

/// EPD Waveform Timing Set Registers 25.
#define EPDWAVE25               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x72))).reg

/// EPD Waveform Timing Set Registers 26.
#define EPDWAVE26               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x74))).reg

/// EPD Waveform Timing Set Registers 27.
#define EPDWAVE27               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x76))).reg

/// EPD Waveform Timing Set Registers 28.
#define EPDWAVE28               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x78))).reg

/// EPD Waveform Timing Set Registers 29.
#define EPDWAVE29               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x7A))).reg

/// EPD Waveform Timing Set Registers 30.
#define EPDWAVE30               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x7C))).reg

/// EPD Waveform Timing Set Registers 31.
#define EPDWAVE31               (*((volatile EPDWAVEN_REG *)(EPDC_REG_BASE_ADDR + 0x7E))).reg

/// ----- RTCLP -----

/// RTC Control Register
#define RTCCTL                  (*((volatile RTCCTL_REG *)(RTCLP_REG_BASE_ADDR + 0x00))).reg

/// RTC Trimming  Control Register
#define RTCTRMCTL               (*((volatile RTCTRMCTL_REG *)(RTCLP_REG_BASE_ADDR + 0x01))).reg

/// RTC Second Alarm Register
#define RTCALM1                 (*((volatile RTCALM1_REG *)(RTCLP_REG_BASE_ADDR + 0x03))).reg

/// RTC Minute Alarm Register
#define RTCALM2                 (*((volatile RTCALM2_REG *)(RTCLP_REG_BASE_ADDR + 0x04))).reg

/// RTC Hour Alarm Register
#define RTCALM3                 (*((volatile RTCALM3_REG *)(RTCLP_REG_BASE_ADDR + 0x05))).reg

/// RTC Stopwatch Control Register
#define RTCSWCTL                (*((volatile RTCSWCTL_REG *)(RTCLP_REG_BASE_ADDR + 0x06))).reg

/// RTC Stopwatch counter Register
#define RTCSWCNT                (*((volatile RTCSWCNT_REG *)(RTCLP_REG_BASE_ADDR + 0x07))).reg

/// RTC divider Register
#define RTCDIV                  (*((volatile RTCDIV_REG *)(RTCLP_REG_BASE_ADDR + 0x08))).reg

/// RTC second Register
#define RTCSEC                  (*((volatile RTCSEC_REG *)(RTCLP_REG_BASE_ADDR + 0x09))).reg

/// RTC Minute Register
#define RTCMIN                  (*((volatile RTCMIN_REG *)(RTCLP_REG_BASE_ADDR + 0x0A))).reg

/// RTC Hour Register
#define RTCHUR                  (*((volatile RTCHUR_REG *)(RTCLP_REG_BASE_ADDR + 0x0B))).reg

/// RTC Day Register
#define RTCDAY                  (*((volatile RTCDAY_REG *)(RTCLP_REG_BASE_ADDR + 0x0C))).reg

/// RTC Month Register
#define RTCMON                  (*((volatile RTCMON_REG *)(RTCLP_REG_BASE_ADDR + 0x0D))).reg

/// RTC Year Register
#define RTCYAR                  (*((volatile RTCYAR_REG *)(RTCLP_REG_BASE_ADDR + 0x0E))).reg

/// RTC Week Register
#define RTCWK                   (*((volatile RTCWK_REG *)(RTCLP_REG_BASE_ADDR + 0x0F))).reg

/// RTC Interrupt Flag Register 1.
#define RTCINTF1                (*((volatile RTCINTF1_REG *)(RTCLP_REG_BASE_ADDR + 0x10))).reg

/// RTC Interrupt Flag Register 2.
#define RTCINTF2                (*((volatile RTCINTF2_REG *)(RTCLP_REG_BASE_ADDR + 0x11))).reg

/// RTC Interrupt Enable Register 1
#define RTCINTE1                (*((volatile RTCINTE1_REG *)(RTCLP_REG_BASE_ADDR + 0x12))).reg

/// RTC Interrupt Enable Register 2
#define RTCINTE2                (*((volatile RTCINTE2_REG *)(RTCLP_REG_BASE_ADDR + 0x13))).reg

/// RTC Down Counter Control Register
#define RTCDCNTCTL              (*((volatile RTCDCNTCTL_REG *)(RTCLP_REG_BASE_ADDR + 0x18))).reg

/// RTC Down Counter Mode Register
#define RTCDCNTMOD              (*((volatile RTCDCNTMOD_REG *)(RTCLP_REG_BASE_ADDR + 0x19))).reg

/// RTC Down Counter Lower Reload Data Register.
#define RTCDCNTRLDL             (*((volatile RTCDCNTRLDL_REG *)(RTCLP_REG_BASE_ADDR + 0x1A))).reg

/// RTC Down Counter Upper Reload Data Register.
#define RTCDCNTRLDH             (*((volatile RTCDCNTRLDH_REG *)(RTCLP_REG_BASE_ADDR + 0x1B))).reg

/// RTC Down Counter Lower Data Register.
#define RTCDCNTL                (*((volatile RTCDCNTL_REG *)(RTCLP_REG_BASE_ADDR + 0x1C))).reg

/// RTC Down Counter Upper Data Register.
#define RTCDCNTH                (*((volatile RTCDCNTH_REG *)(RTCLP_REG_BASE_ADDR + 0x1D))).reg

/// Power Control Register
#define PWRCTL                  (*((volatile PWRCTL_REG *)(RTCLP_REG_BASE_ADDR + 0x20))).reg

/// P2 Input Data Register
#define P2IN                    (*((volatile P2IN_REG *)(RTCLP_REG_BASE_ADDR + 0x30))).reg

/// P2 Output Data Register
#define P2OUT                   (*((volatile P2OUT_REG *)(RTCLP_REG_BASE_ADDR + 0x31))).reg

/// P2 Output Enable Register
#define P2OEN                   (*((volatile P2OEN_REG *)(RTCLP_REG_BASE_ADDR + 0x32))).reg

/// P2 Input Enable Register
#define P2IEN                   (*((volatile P2IEN_REG *)(RTCLP_REG_BASE_ADDR + 0x33))).reg

/// P2 Pull-up/down Enable Register
#define P2REN                   (*((volatile P2REN_REG *)(RTCLP_REG_BASE_ADDR + 0x34))).reg

/// P2 Pull-up/down Control Register
#define P2PDPU                  (*((volatile P2PDPU_REG *)(RTCLP_REG_BASE_ADDR + 0x35))).reg

/// P2 Port Interrupt Flag Register
#define P2INTF                  (*((volatile P2INTF_REG *)(RTCLP_REG_BASE_ADDR + 0x36))).reg

/// P2 Port Interrupt Control Register
#define P2INTE                  (*((volatile P2INTE_REG *)(RTCLP_REG_BASE_ADDR + 0x38))).reg

/// P2 Port Interrupt Edge Control Register
#define P2IEDGE                 (*((volatile P2IEDGE_REG *)(RTCLP_REG_BASE_ADDR + 0x39))).reg

/// P2 Port Chattering Filter Enable Register
#define P2CHATEN                (*((volatile P2CHATEN_REG *)(RTCLP_REG_BASE_ADDR + 0x3A))).reg

/// P2 Port Mode Select Register
#define P2MODSEL                (*((volatile P2MODSEL_REG *)(RTCLP_REG_BASE_ADDR + 0x3C))).reg

/// P2 Port Function Select Register
#define P2FNCSEL0               (*((volatile P2FNCSEL0_REG *)(RTCLP_REG_BASE_ADDR + 0x3E))).reg

/// OSC1 Load Capacitance 1 Control Register
#define OSC1CL1                 (*((volatile OSC1CL1_REG *)(RTCLP_REG_BASE_ADDR + 0x40))).reg

/// OSC1 Load Capacitance 2 Control Register
#define OSC1CL2                 (*((volatile OSC1CL2_REG *)(RTCLP_REG_BASE_ADDR + 0x41))).reg

/// VOSC Regulator Control Register
#define VOSCCTL                 (*((volatile VOSCCTL_REG *)(RTCLP_REG_BASE_ADDR + 0x42))).reg

/// VOSC Reference Current Adjustment Register
#define VOSCTRIM                (*((volatile VOSCTRIM_REG *)(RTCLP_REG_BASE_ADDR + 0x43))).reg

/// RTCLPCLK Control Register
#define F32KCTL                 (*((volatile F32KCTL_REG *)(RTCLP_REG_BASE_ADDR + 0x44))).reg


#ifdef __cplusplus
}
#endif

#endif // C17F63_REG_H__
