/************************************************************************//**
 *
 * @file    pport_f63_reg.h
 *
 * @brief   Definition of the I/O Ports(PPORT) Register for S1C17F63.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2018-2019. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Jun. 2018    1.00
 *              - First revision.
 *          - 01 Nov. 2018    1.10
 *              - Change source code.
 *          - 19 Jun. 2019    1.20
 *              - Change source code.
 *          - 11 Sep. 2019    1.30
 *              - Change source code.
 *
 ******************************************************************************/
#ifndef PPORT_REG_H__
#define PPORT_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

/// P0 Port Data Register
typedef union P0DAT_REG_TAG {
    unsigned short  reg;
    struct P0DAT_REG_BIT_TAG {
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P00IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P00IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P01IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P01IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P02IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P02IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P03IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P03IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P04IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P04IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P05IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P05IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P06IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P06IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P07IN
         *  The GPIO port pin status can be read out from these bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P07IN       : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P00OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P00OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P01OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P01OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P02OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P02OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P03OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P03OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P04OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P04OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P05OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P05OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P06OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P06OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P07OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P07OUT      : 1;
    } bit;
    unsigned char   byte_reg[2];
} P0DAT_REG;

/// P0 Port Enable Register
typedef union P0IOEN_REG_TAG {
    unsigned short  reg;
    struct P0IOEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the GPIO port output.
         * .P00OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P00OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P01OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P01OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P02OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P02OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P03OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P03OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P04OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P04OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P05OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P05OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P06OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P06OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P07OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P07OEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P00IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P00IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P01IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P01IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P02IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P02IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P03IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P03IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P04IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P04IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P05IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P05IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P06IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P06IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P07IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P07IEN      : 1;
    } bit;
    unsigned char   byte_reg[2];
} P0IOEN_REG;

/// P0 Port Pull-up/down Control Register
typedef union P0RCTL_REG_TAG {
    unsigned short  reg;
    struct P0RCTL_REG_BIT_TAG {
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P00REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P00REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P01REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P01REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P02REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P02REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P03REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P03REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P04REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P04REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P05REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P05REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P06REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P06REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P07REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P07REN      : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P00PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P00PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P01PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P01PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P02PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P02PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P03PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P03PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P04PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P04PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P05PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P05PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P06PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P06PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P07PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P07PDPU     : 1;
    } bit;
    unsigned char   byte_reg[2];
} P0RCTL_REG;

/// P0 Port Interrupt Flag Register
typedef union P0INTF_REG_TAG {
    unsigned short  reg;
    struct P0INTF_REG_BIT_TAG {
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P00IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P00IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P01IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P01IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P02IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P02IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P03IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P03IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P04IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P04IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P05IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P05IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P06IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P06IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P07IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P07IF       : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P0INTF_REG;

/// P0 Port Interrupt Control Register
typedef union P0INTCTL_REG_TAG {
    unsigned short  reg;
    struct P0INTCTL_REG_BIT_TAG {
        /**
         * This bit enable port input interrupt.
         * .P00IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P00IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P01IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P01IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P02IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P02IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P03IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P03IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P04IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P04IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P05IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P05IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P06IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P06IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P07IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P07IE       : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P00EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P00EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P01EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P01EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P02EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P02EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P03EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P03EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P04EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P04EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P05EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P05EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P06EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P06EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P07EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P07EDGE     : 1;
    } bit;
    unsigned char   byte_reg[2];
} P0INTCTL_REG;

/// P0 Port Chattering Filter Enable Register
typedef union P0CHATEN_REG_TAG {
    unsigned short  reg;
    struct P0CHATEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the chattering filter function.
         * .P00CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P00CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P01CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P01CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P02CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P02CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P03CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P03CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P04CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P04CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P05CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P05CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P06CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P06CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P07CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P07CHATEN   : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P0CHATEN_REG;

/// P0 Port Mode Select Register
typedef union P0MODSEL_REG_TAG {
    unsigned short  reg;
    struct P0MODSEL_REG_BIT_TAG {
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P00SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P00SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P01SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P01SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P02SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P02SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P03SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P03SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P04SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P04SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P05SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P05SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P06SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P06SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P07SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P07SEL      : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P0MODSEL_REG;

/// P0 Port Function Select Register
typedef union P0FNCSEL_REG_TAG {
    unsigned short  reg;
    struct P0FNCSEL_REG_BIT_TAG {
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P00MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P00MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P01MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P01MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P02MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P02MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P03MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P03MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P04MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P04MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P05MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P05MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P06MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P06MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P07MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P0nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P07MUX      : 2;
    } bit;
    unsigned char   byte_reg[2];
} P0FNCSEL_REG;

/// P1 Port Data Register
typedef union P1DAT_REG_TAG {
    unsigned short  reg;
    struct P1DAT_REG_BIT_TAG {
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P10IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P10IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P11IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P11IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P12IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P12IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P13IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P13IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P14IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P14IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .P15IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      P15IN       : 1;
        unsigned short      reserved_1  : 2;    ///< Reserved.
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P10OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P10OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P11OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P11OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P12OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P12OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P13OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P13OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P14OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P14OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .P15OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      P15OUT      : 1;
        unsigned short      reserved_2  : 2;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P1DAT_REG;

/// P1 Port Enable Register
typedef union P1IOEN_REG_TAG {
    unsigned short  reg;
    struct P1IOEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the GPIO port output.
         * .P10OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P10OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P11OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P11OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P12OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P12OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P13OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P13OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P14OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P14OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .P15OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      P15OEN      : 1;
        unsigned short      reserved_1  : 2;    ///< Reserved.
        /**
         * This bit enable/disable the GPIO port input.
         * .P10IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P10IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P11IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P11IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P12IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P12IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P13IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P13IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P14IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P14IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .P15IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      P15IEN      : 1;
        unsigned short      reserved_2  : 2;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P1IOEN_REG;

/// P1 Port Pull-up/down Control Register
typedef union P1RCTL_REG_TAG {
    unsigned short  reg;
    struct P1RCTL_REG_BIT_TAG {
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P10REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P10REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P11REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P11REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P12REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P12REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P13REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P13REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P14REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P14REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .P15REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      P15REN      : 1;
        unsigned short      reserved_1  : 2;    ///< Reserved.
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P10PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P10PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P11PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P11PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P12PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P12PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P13PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P13PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P14PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P14PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .P15PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      P15PDPU     : 1;
        unsigned short      reserved_2  : 2;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P1RCTL_REG;

/// P1 Port Interrupt Flag Register
typedef union P1INTF_REG_TAG {
    unsigned short  reg;
    struct P1INTF_REG_BIT_TAG {
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P10IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P10IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P11IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P11IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P12IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P12IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P13IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P13IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P14IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P14IF       : 1;
        /**
         * This bit indicate the port input interrupt cause occurrence status.
         * .P15IF
         *  This bit indicate the port input interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      P15IF       : 1;
        unsigned short      reserved_1  :10;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P1INTF_REG;

/// P1 Port Interrupt Control Register
typedef union P1INTCTL_REG_TAG {
    unsigned short  reg;
    struct P1INTCTL_REG_BIT_TAG {
        /**
         * This bit enable port input interrupt.
         * .P10IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P10IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P11IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P11IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P12IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P12IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P13IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P13IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P14IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P14IE       : 1;
        /**
         * This bit enable port input interrupt.
         * .P15IE
         *  This bit enable port input interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      P15IE       : 1;
        unsigned short      reserved_1  : 2;    ///< Reserved.
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P10EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P10EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P11EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P11EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P12EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P12EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P13EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P13EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P14EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P14EDGE     : 1;
        /**
         * This bit select the input signal edge to generate a port input interrupt.
         * .P15EDGE
         *  This bit select the input signal edge to generate a port input interrupt.
         *    1 (R/W): An interrupt will occur at a falling edge.
         *    0 (R/W): An interrupt will occur at a rising edge.
         */
        unsigned short      P15EDGE     : 1;
        unsigned short      reserved_2  : 2;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P1INTCTL_REG;

/// P1 Port Chattering Filter Enable Register
typedef union P1CHATEN_REG_TAG {
    unsigned short  reg;
    struct P1CHATEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the chattering filter function.
         * .P10CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P10CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P11CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P11CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P12CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P12CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P13CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P13CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P14CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P14CHATEN   : 1;
        /**
         * This bit enable/disable the chattering filter function.
         * .P15CHATEN
         *  This bit enable/disable the chattering filter function.
         *    1 (R/W): Enable (The chattering filter is used.)
         *    0 (R/W): Disable (The chattering filter is bypassed.)
         */
        unsigned short      P15CHATEN   : 1;
        unsigned short      reserved_1  :10;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P1CHATEN_REG;

/// P1 Port Mode Select Register
typedef union P1MODSEL_REG_TAG {
    unsigned short  reg;
    struct P1MODSEL_REG_BIT_TAG {
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P10SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P10SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P11SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P11SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P12SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P12SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P13SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P13SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P14SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P14SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .P15SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      P15SEL      : 1;
        unsigned short      reserved_1  :10;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P1MODSEL_REG;

/// P1 Port Function Select Register
typedef union P1FNCSEL_REG_TAG {
    unsigned short  reg;
    struct P1FNCSEL_REG_BIT_TAG {
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P10MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P1nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P10MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P11MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P1nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P11MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P12MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P1nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P12MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P13MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P1nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P13MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P14MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P1nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P14MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .P15MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | P1nMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      P15MUX      : 2;
        unsigned short      reserved_1  : 4;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} P1FNCSEL_REG;

/// Pd Port Data Register
typedef union PDDAT_REG_TAG {
    unsigned short  reg;
    struct PDDAT_REG_BIT_TAG {
        /**
         * The GPIO port pin status can be read out from this bit.
         * .PD0IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      PD0IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .PD1IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      PD1IN       : 1;
        /**
         * The GPIO port pin status can be read out from this bit.
         * .PD2IN
         *  The GPIO port pin status can be read out from this bit.
         *    1 (R): Port pin = High level
         *    0 (R): Port pin = Low level
         */
        unsigned short      PD2IN       : 1;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .PD0OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      PD0OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .PD1OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      PD1OUT      : 1;
        /**
         * This bit is used to set data to be output from the GPIO port pin.
         * .PD2OUT
         *  This bit is used to set data to be output from the GPIO port pin.
         *    1 (R/W): Output high level from the port pin
         *    0 (R/W): Output low level from the port pin
         */
        unsigned short      PD2OUT      : 1;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} PDDAT_REG;

/// Pd Port Enable Register
typedef union PDIOEN_REG_TAG {
    unsigned short  reg;
    struct PDIOEN_REG_BIT_TAG {
        /**
         * This bit enable/disable the GPIO port output.
         * .PD0OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      PD0OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .PD1OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      PD1OEN      : 1;
        /**
         * This bit enable/disable the GPIO port output.
         * .PD2OEN
         *  This bit enable/disable the GPIO port output.
         *    1 (R/W): Enable (Data is output from the port pin.)
         *    0 (R/W): Disable (The port is placed into Hi-Z.)
         */
        unsigned short      PD2OEN      : 1;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * This bit enable/disable the GPIO port input.
         * .PD0IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      PD0IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .PD1IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      PD1IEN      : 1;
        /**
         * This bit enable/disable the GPIO port input.
         * .PD2IEN
         *  This bit enable/disable the GPIO port input.
         *    1 (R/W): Enable (The port pin status is input.)
         *    0 (R/W): Disable (Input data is fixed at 0.)
         */
        unsigned short      PD2IEN      : 1;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} PDIOEN_REG;

/// Pd Port Pull-up/down Control Register
typedef union PDRCTL_REG_TAG {
    unsigned short  reg;
    struct PDRCTL_REG_BIT_TAG {
        /**
         * This bit enable/disable the port pull-up/down control.
         * .PD0REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      PD0REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .PD1REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      PD1REN      : 1;
        /**
         * This bit enable/disable the port pull-up/down control.
         * .PD2REN
         *  This bit enable/disable the port pull-up/down control.
         *    1 (R/W): Enable (The built-in pull-up/down resistor is used.)
         *    0 (R/W): Disable (No pull-up/down control is performed.)
         */
        unsigned short      PD2REN      : 1;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .PD0PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      PD0PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .PD1PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      PD1PDPU     : 1;
        /**
         * This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
         * .PD2PDPU
         *  This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into
         *  the port.
         *    1 (R/W): Pull-up resistor
         *    0 (R/W): Pull-down resistor
         */
        unsigned short      PD2PDPU     : 1;
        unsigned short      reserved_2  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} PDRCTL_REG;

/// Pd Port Mode Select Register
typedef union PDMODSEL_REG_TAG {
    unsigned short  reg;
    struct PDMODSEL_REG_BIT_TAG {
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .PD0SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      PD0SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .PD1SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      PD1SEL      : 1;
        /**
         * This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         * .PD2SEL
         *  This bit select whether each port is used for the GPIO function or a peripheral I/O function.
         *    1 (R/W): Use peripheral I/O function
         *    0 (R/W): Use GPIO function
         */
        unsigned short      PD2SEL      : 1;
        unsigned short      reserved_1  :13;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} PDMODSEL_REG;

/// Pd Port Function Select Register
typedef union PDFNCSEL_REG_TAG {
    unsigned short  reg;
    struct PDFNCSEL_REG_BIT_TAG {
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .PD0MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | PDnMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      PD0MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .PD1MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | PDnMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      PD1MUX      : 2;
        /**
         * These bits select the peripheral I/O function to be assigned to each port pin.
         * .PD2MUX[1:0]
         *  These bits select the peripheral I/O function to be assigned to each port pin.
         * +-------------+-------------------------+
         * | PDnMUX[1:0] | Peripheral I/O function |
         * +-------------+-------------------------+
         * |     0x3     |       Function 3        |
         * +-------------+-------------------------+
         * |     0x2     |       Function 2        |
         * +-------------+-------------------------+
         * |     0x1     |       Function 1        |
         * +-------------+-------------------------+
         * |     0x0     |       Function 0        |
         * +-------------+-------------------------+
         */
        unsigned short      PD2MUX      : 2;
        unsigned short      reserved_1  :10;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} PDFNCSEL_REG;

/// P Port Clock Control Register
typedef union PCLK_REG_TAG {
    unsigned short  reg;
    struct PCLK_REG_BIT_TAG {
        /**
         * These bits select the clock source of PPORT (chattering filter).
         * .CLKSRC[1:0]
         *  These bits select the clock source of PPORT (chattering filter).
         * .CLKDIV[3:0]
         *  These bits select the division ratio of the PPORT operating clock (chattering filter clock).
         * +-------------+-----------------------------------+
         * |             |           CLKSRC[1:0]             |
         * |             +--------+--------+--------+--------+
         * | CLKDIV[3:0  |  0x0   |   0x1  |  0x2   |  0x3   |
         * |             +--------+--------+--------+--------+
         * |             |  IOSC  |  OSC1  |  OSC3  | EXOSC  |
         * +-------------+--------+--------+--------+--------+
         * |     0xf     |         1/32,768         | 1/1    |
         * +-------------+--------------------------+        +
         * |     0xe     |         1/16,384         |        |
         * +-------------+--------------------------+        +
         * |     0xd     |          1/8,192         |        |
         * +-------------+--------------------------+        +
         * |     0xc     |          1/4,096         |        |
         * +-------------+--------------------------+        +
         * |     0xb     |          1/2,048         |        |
         * +-------------+--------------------------+        +
         * |     0xa     |          1/1,024         |        |
         * +-------------+--------------------------+        +
         * |     0x9     |           1/512          |        |
         * +-------------+--------------------------+        +
         * |     0x8     |           1/256          |        |
         * +-------------+--------------------------+        +
         * |     0x7     |           1/128          |        |
         * +-------------+--------------------------+        +
         * |     0x6     |           1/64           |        |
         * +-------------+--------------------------+        +
         * |     0x5     |           1/32           |        |
         * +-------------+--------------------------+        +
         * |     0x4     |           1/16           |        |
         * +-------------+--------------------------+        +
         * |     0x3     |           1/8            |        |
         * +-------------+--------------------------+        +
         * |     0x2     |           1/4            |        |
         * +-------------+--------------------------+        +
         * |     0x1     |           1/2            |        |
         * +-------------+--------------------------+        +
         * |     0x0     |           1/1            |        |
         * +-------------+-------------------------+--------+
         */
        unsigned short      CLKSRC      : 2;
        /**
         * These bits configure the key-entry reset function.
         * .KRSTCFG[1:0]
         *  These bits configure the key-entry reset function.
         * +--------------+-------------------------------------+
         * | KRSTCFG[1:0] |           key-entry reset           |
         * +--------------+-------------------------------------+
         * |     0x3      | Reset when P0[3:0] inputs = all low |
         * +--------------+-------------------------------------+
         * |     0x2      | Reset when P0[2:0] inputs = all low |
         * +--------------+-------------------------------------+
         * |     0x1      | Reset when P0[1:0] inputs = all low |
         * +--------------+-------------------------------------+
         * |     0x0      |               Disable               |
         * +--------------+-------------------------------------+
         */
        unsigned short      KRSTCFG     : 2;
        /**
         * These bits select the division ratio of the PPORT operating clock (chattering filter clock).
         * .CLKSRC[1:0]
         *  These bits select the clock source of PPORT (chattering filter).
         * .CLKDIV[3:0]
         *  These bits select the division ratio of the PPORT operating clock (chattering filter clock).
         * +-------------+-----------------------------------+
         * |             |           CLKSRC[1:0]             |
         * |             +--------+--------+--------+--------+
         * | CLKDIV[3:0  |  0x0   |   0x1  |  0x2   |  0x3   |
         * |             +--------+--------+--------+--------+
         * |             |  IOSC  |  OSC1  |  OSC3  | EXOSC  |
         * +-------------+--------+--------+--------+--------+
         * |     0xf     |         1/32,768         | 1/1    |
         * +-------------+--------------------------+        +
         * |     0xe     |         1/16,384         |        |
         * +-------------+--------------------------+        +
         * |     0xd     |          1/8,192         |        |
         * +-------------+--------------------------+        +
         * |     0xc     |          1/4,096         |        |
         * +-------------+--------------------------+        +
         * |     0xb     |          1/2,048         |        |
         * +-------------+--------------------------+        +
         * |     0xa     |          1/1,024         |        |
         * +-------------+--------------------------+        +
         * |     0x9     |           1/512          |        |
         * +-------------+--------------------------+        +
         * |     0x8     |           1/256          |        |
         * +-------------+--------------------------+        +
         * |     0x7     |           1/128          |        |
         * +-------------+--------------------------+        +
         * |     0x6     |           1/64           |        |
         * +-------------+--------------------------+        +
         * |     0x5     |           1/32           |        |
         * +-------------+--------------------------+        +
         * |     0x4     |           1/16           |        |
         * +-------------+--------------------------+        +
         * |     0x3     |           1/8            |        |
         * +-------------+--------------------------+        +
         * |     0x2     |           1/4            |        |
         * +-------------+--------------------------+        +
         * |     0x1     |           1/2            |        |
         * +-------------+--------------------------+        +
         * |     0x0     |           1/1            |        |
         * +-------------+-------------------------+--------+
         */
        unsigned short      CLKDIV      : 4;
        /**
         * This bit sets whether the PPORT operating clock is supplied in DEBUG mode or not.
         * .DBRUN
         *  This bit sets whether the PPORT operating clock is supplied in DEBUG mode or not.
         *    1 (R/WP): Clock supplied in DEBUG mode
         *    0 (R/WP): No clock supplied in DEBUG mode
         */
        unsigned short      DBRUN       : 1;
        unsigned short      reserved_1  : 7;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} PCLK_REG;

/// P Port Interrupt Flag Group Register
typedef union PINTFGRP_REG_TAG {
    unsigned short  reg;
    struct PINTFGRP_REG_BIT_TAG {
        /**
         * This bit indicate that P0 port group includes a port that has generated an interrupt.
         * .P0INT
         *  This bit indicate that Px port group includes a port that has generated an interrupt.
         *    1 (R): A port generated an interrupt
         *    0 (R): No port generated an interrupt
         */
        unsigned short      P0INT       : 1;
        /**
         * This bit indicate that P1 port group includes a port that has generated an interrupt.
         * .P1INT
         *  This bit indicate that Px port group includes a port that has generated an interrupt.
         *    1 (R): A port generated an interrupt
         *    0 (R): No port generated an interrupt
         */
        unsigned short      P1INT       : 1;
        /**
         * This bit indicate that P2 port group includes a port that has generated an interrupt.
         * .P2INT
         *  This bit indicate that Px port group includes a port that has generated an interrupt.
         *    1 (R): A port generated an interrupt
         *    0 (R): No port generated an interrupt
         */
        unsigned short      P2INT       : 1;
        unsigned short      reserved_1  :13;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} PINTFGRP_REG;

#ifdef __cplusplus
}
#endif

#endif // PPORT_REG_H__
