/************************************************************************//**
 *
 * @file    spislv_sel_reg.h
 *
 * @brief   Definition of the SPI Slave Selector(RTCLP) Register.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2018-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Jun. 2018    1.00
 *              - First revision.
 *
 ******************************************************************************/
#ifndef SPISLV_SEL_REG_H__
#define SPISLV_SEL_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

/// SPI Slave Select Register
typedef union SPISLVSEL_REG_TAG {
    unsigned short  reg;
    struct SPISLVSEL_REG_BIT_TAG {
        /**
         * These bits select the SPI slave device in the RTCLP to be accessed.
         * .SLV[2:0]
         *  These bits select the SPI slave device in the RTCLP to be accessed.
         * +----------+--------------+
         * | SLV[2:0] | Slave device |
         * +----------+--------------+
         * |  0b100   |  SPI slave 2 |
         * +----------+--------------+
         * |  0b*10   |  SPI slave 1 |
         * +----------+--------------+
         * |  0b**1   |  SPI slave 0 |
         * +----------+--------------+
         * |  0b000   | Not selected |
         * +----------+--------------+
         */
        unsigned short      SLV         : 3;
        unsigned short      reserved_1  :13;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} SPISLVSEL_REG;

#ifdef __cplusplus
}
#endif

#endif // SPISLV_SEL_REG_H__
