/************************************************************************//**
 *
 * @file    tsrvr_reg.h
 *
 * @brief   Definition of the TSRVR Register.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2016-2019. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *          - 01 Jun. 2018    1.10
 *              - Change source code.
 *          - 01 Nov. 2018    1.20
 *              - Change source code.
 *          - 19 Jun. 2019    1.30
 *              - Change source code.
 *
 ******************************************************************************/
#ifndef TSRVR_REG_H__
#define TSRVR_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <c17_mcu_select.h>

/// TSRVR Ch.N Temperature Sensor Control Register
typedef union TSRVRNTCTL_REG_TAG {
    unsigned short  reg;
    struct TSRVRNTCTL_REG_BIT_TAG {
        /**
         * This bit enables the temperature sensor operation.
         * .TEMPEN
         *  This bit enables the temperature sensor operation.
         *    1 (R/W): Enable temperature sensor output
         *    0 (R/W): Disable temperature sensor output
         */
        unsigned short      TEMPEN      : 1;
        unsigned short      reserved_1  :15;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} TSRVRNTCTL_REG;

/// TSRVR Ch.N Reference Voltage Generator Control Register
typedef union TSRVRNVCTL_REG_TAG {
    unsigned short  reg;
    struct TSRVRNVCTL_REG_BIT_TAG {
        /**
         * These bits set the reference voltage generator output voltage.
         * .VREFAMD[1:0]
         *  These bits set the reference voltage generator output voltage.
         * +--------------+-----------------+
         * | VREFAMD[1:0] | Output voltage  |
         * +--------------+-----------------+
         * |    0x3       |  2.5V output    |
         * +--------------+-----------------+
         * |    0x2       |  2.0V output    |
         * +--------------+-----------------+
         * |    0x1       | Vdd level output|
         * +--------------+-----------------+
         * |    0x0       |   Hi-Z          |
         * +--------------+-----------------+
         */
        unsigned short      VREFAMD     : 2;
        unsigned short      reserved_1  :14;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} TSRVRNVCTL_REG;



#ifdef __cplusplus
}
#endif

#endif // TSRVR_REG_H__
