/************************************************************************//**
 *
 * @file    upmux_f63_reg.h
 *
 * @brief   Definition of the Universal Port Multiplexer(UPMUX) Register.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2018-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Jun. 2018    1.00
 *              - First revision.
 *
 ******************************************************************************/
#ifndef UPMUX_REG_H__
#define UPMUX_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

/// P00-01 Universal Port Multiplexer Setting Register
typedef union P0UPMUX0_REG_TAG {
    unsigned short  reg;
    struct P0UPMUX0_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P00PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P00PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P00PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P01PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P01PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P01PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P0UPMUX0_REG;

/// P02-03 Universal Port Multiplexer Setting Register
typedef union P0UPMUX1_REG_TAG {
    unsigned short  reg;
    struct P0UPMUX1_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P02PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P02PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P02PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P03PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P03PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P03PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P0UPMUX1_REG;

/// P04-05 Universal Port Multiplexer Setting Register
typedef union P0UPMUX2_REG_TAG {
    unsigned short  reg;
    struct P0UPMUX2_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P04PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P04PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P04PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P05PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P05PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P05PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P0UPMUX2_REG;

/// P06-07 Universal Port Multiplexer Setting Register
typedef union P0UPMUX3_REG_TAG {
    unsigned short  reg;
    struct P0UPMUX3_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P06PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P06PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P06PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P07PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P07PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P07PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P0UPMUX3_REG;

/// P10-11 Universal Port Multiplexer Setting Register
typedef union P1UPMUX0_REG_TAG {
    unsigned short  reg;
    struct P1UPMUX0_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P10PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P10PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P10PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P11PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P11PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P11PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P1UPMUX0_REG;

/// P12-13 Universal Port Multiplexer Setting Register
typedef union P1UPMUX1_REG_TAG {
    unsigned short  reg;
    struct P1UPMUX1_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P12PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P12PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P12PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P13PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P13PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P13PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P1UPMUX1_REG;

/// P14-15 Universal Port Multiplexer Setting Register
typedef union P1UPMUX2_REG_TAG {
    unsigned short  reg;
    struct P1UPMUX2_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P14PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P14PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P14PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P15PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P15PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |   T16B    | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |   0x0    |   0x0    |  0x0,0x1  |    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |   Ch.0   |   Ch.0   |  Ch.0,1   |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         */
        unsigned short      P15PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P1UPMUX2_REG;

#ifdef __cplusplus
}
#endif

#endif // UPMUX_REG_H__
