/************************************************************************//**
 *
 * @file    c17_i2c.h
 *
 * @brief   This is I2C driver header file.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2017. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *          - 01 Oct. 2017    1.10
 *              - Modify comment.
 *
 ***************************************************************************/
#ifndef C17_I2C_H__
#define C17_I2C_H__

#include <c17_mcu_select.h>

/* --- definition --- */
enum
{
	C17_I2C_SLAVE,				///< Slave mode.
	C17_I2C_MASTER				///< Master mode.
};

enum
{
	C17_I2C_IOSC,				///< Clock Source = IOSC
	C17_I2C_OSC1,				///< Clock Source = OSC1
	C17_I2C_OSC3,				///< Clock Source = OSC3
	C17_I2C_EXT					///< Clock Source = External
};

enum
{
	C17_I2C_CLKDIV_1,			///< Clock Division 1/1
	C17_I2C_CLKDIV_2,			///< Clock Division 1/2
	C17_I2C_CLKDIV_4,			///< Clock Division 1/4
	C17_I2C_CLKDIV_8			///< Clock Division 1/8
};

enum
{
	C17_I2C_STS_NACK = 0x8001,	///< I2C status : NACK reception.
	C17_I2C_STS_ERR,			///< I2C status : Error detection.
	C17_I2C_STS_START_CONDITION,///< I2C status : Start Condition detection.
	C17_I2C_STS_STOP_CONDITION,	///< I2C status : Stop Condition detection.
	C17_I2C_STS_RCVBUF_FULL		///< I2C status : Receive buff full.
};

/* --- external declaration --- */
extern void c17intI2c(void)	__attribute__ ((interrupt_handler));

extern void c17initI2c(void);
extern void c17setI2C(unsigned short i2cMode, unsigned short i2cClkSrc, unsigned short i2cClkDiv, unsigned long i2cBrt);
extern void c17setSlvAddressI2C(unsigned short i2cAddress);
extern void c17startI2c(void);
extern void c17stopI2c(void);
extern void c17enableIntI2c(void);
extern void c17disableIntI2c(void);
extern int c17sendI2cMstData(unsigned short i2cAddress, unsigned char *i2cData, int i2cDataSize);
extern int c17rcvI2cMstData(unsigned short i2cAddress, unsigned char *i2cData, int i2cDataSize);
extern int c17sendI2cSlvData(unsigned char *i2cData, int i2cDataSize);
extern int c17rcvI2cSlvData(unsigned char *i2cData, int i2cDataSize);

#endif	// C17_I2C_H__

