/************************************************************************//**
 *
 * @file    c17_init_config.h
 *
 * @brief   This is initialize macro header.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *
 ***************************************************************************/
#ifndef C17_INIT_CONFIG_H_
#define C17_INIT_CONFIG_H_

#define C17_PE_ADC
#define C17_PE_EEPROMC
#define C17_PE_EPDC
#define C17_PE_I2C_MASTER
//#define C17_PE_I2C_SLAVE
#define C17_PE_PORT
#define C17_PE_PWG
#define C17_PE_RTCLP
#define C17_PE_SNDA
#define C17_PE_SPIA_MASTER
//#define C17_PE_SPIA_SLAVE
#define C17_PE_SVD
#define C17_PE_T16
#define C17_PE_T16B
#define C17_PE_TSRVR
#define C17_PE_UART_MASTER
//#define C17_PE_UART_SLAVE
#define C17_PE_WDT


/// --- BEGIN EPDC Setting ---

/**
 * Internal definition macro
 * Do not change.
 */

#define EPDC_enable				(1)			/// --- Do not change. ---
#define EPDC_disable			(0)			/// --- Do not change. ---
#define EPDC_IOSC				(0)			/// --- Do not change. ---
#define EPDC_OSC1				(1)			/// --- Do not change. ---
#define EPDC_OSC3				(2)			/// --- Do not change. ---
#define EPDC_EXOSC				(3)			/// --- Do not change. ---
#define EPDC_CLKDIV_OSC1_1		(0)			/// --- Do not change. ---
#define EPDC_CLKDIV_OSC1_2		(1)			/// --- Do not change. ---
#define EPDC_CLKDIV_OSC1_4		(2)			/// --- Do not change. ---
#define EPDC_CLKDIV_OSC1_8		(3)			/// --- Do not change. ---
#define EPDC_CLKDIV_OSC1_16		(4)			/// --- Do not change. ---
#define EPDC_CLKDIV_OSC1_32		(5)			/// --- Do not change. ---
#define EPDC_CLKDIV_OSC1_64		(6)			/// --- Do not change. ---
#define EPDC_CLKDIV_OSC1_128	(7)			/// --- Do not change. ---
#define EPDC_CLKDIV_IOSC_OSC3_128	(0)			/// --- Do not change. ---
#define EPDC_CLKDIV_IOSC_OSC3_256	(1)			/// --- Do not change. ---
#define EPDC_CLKDIV_IOSC_OSC3_512	(2)			/// --- Do not change. ---
#define EPDC_CLKDIV_IOSC_OSC3_1024	(3)			/// --- Do not change. ---
#define EPDC_CLKDIV_IOSC_OSC3_2048	(4)			/// --- Do not change. ---
#define EPDC_CLKDIV_IOSC_OSC3_4096	(5)			/// --- Do not change. ---
#define EPDC_CLKDIV_IOSC_OSC3_8192	(6)			/// --- Do not change. ---
#define EPDC_CLKDIV_IOSC_OSC3_16384	(7)			/// --- Do not change. ---
#define EPDC_INIT(a, b, c)		(((EPDC_##a) << 5) + ((EPDC_##b) << 3) + (EPDC_##c))	/// --- Do not change. ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_EPDC	(3)				/// Set EPDC interrupt level  0 to 7

/**
 * EPDC Setting
 * Please change the argument, if necessary.
 *  - 1st:Module activate(enable,disable)
 *  - 2nd:Clock source(IOSC,OSC1,OSC3,EXOSC)
 *  - 3rd:Clock division
 *          IOSC,OSC3(CLKDIV_IOSC_OSC3_xx:128,256,512,1024,2048,4096,8192,16384)
 *          OSC1(CLKDIV_OSC1_xx:1,2,4,8,16,32,64,128)
 *          EXT(CLKDIV_1)
 *
 * example.
 * #define EPDC_SET_INIT EPDC_INIT(enable, OSC3, CLKDIV_IOSC_OSC3_256)
 */

#define EPDC_SET_INIT EPDC_INIT(enable, OSC1, CLKDIV_OSC1_128)

/// --- END EPDC Setting ---


/// --- BEGIN CLG Setting ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_CLG	(3)			/// Set CLG interrupt level  0 to 7

/// --- END CLG Setting ---


/// --- BEGIN ADC12A Setting ---

/**
 * Internal definition macro
 * Do not change.
 */

#define ADC_enable				(1)			/// --- Do not change. ---
#define ADC_disable				(0)			/// --- Do not change. ---
#define ADC_onetime				(0)			/// --- Do not change. ---
#define ADC_continuous			(1)			/// --- Do not change. ---
#define ADC_soft				(0)			/// --- Do not change. ---
#define ADC_t16					(1)			/// --- Do not change. ---
#define ADC_ext					(3)			/// --- Do not change. ---
#define ADC_startAin0			(0)			/// --- Do not change. ---
#define ADC_startAin1			(1)			/// --- Do not change. ---
#define ADC_startAin2			(2)			/// --- Do not change. ---
#define ADC_startAin3			(3)			/// --- Do not change. ---
#define ADC_startAin4			(4)			/// --- Do not change. ---
#define ADC_startAin5			(5)			/// --- Do not change. ---
#define ADC_startAin6			(6)			/// --- Do not change. ---
#define ADC_startAin7			(7)			/// --- Do not change. ---
#define ADC_endAin0				(0)			/// --- Do not change. ---
#define ADC_endAin1				(1)			/// --- Do not change. ---
#define ADC_endAin2				(2)			/// --- Do not change. ---
#define ADC_endAin3				(3)			/// --- Do not change. ---
#define ADC_endAin4				(4)			/// --- Do not change. ---
#define ADC_endAin5				(5)			/// --- Do not change. ---
#define ADC_endAin6				(6)			/// --- Do not change. ---
#define ADC_endAin7				(7)			/// --- Do not change. ---
#define ADC_INIT(a, b, c, d, e)	(((ADC_##a) << 9) + ((ADC_##b) << 8) + ((ADC_##c) << 6) + ((ADC_##d) << 3) + (ADC_##e))	/// --- Do not change. ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_ADC0	(3)			/// Set ADC12A CH.0 interrupt level  0 to 7

/**
 * ADC Setting
 * Please change the argument, if necessary.
 *  - 1st:Module activate(enable,disable)
 *  - 2nd:Mode(onetime,continuous)
 *  - 3rd:Trigger source(soft,t16,ext)
 *  - 4th:Start Channel(startAin0,startAin1,startAin2,startAin3,startAin4,startAin05,startAin6,startAin7)
 *  - 5th:End Channel(endAin0,endAin1,endAin2,endAin3,endAin4,endAin05,endAin6,endAin7)
 *
 * example.
 * #define ADCCH0_INIT ADC_INIT(enable, onetime, t16, right, startAin0, endAin7)
 */

#define ADCCH0_INIT ADC_INIT(enable, onetime, t16, startAin0, endAin0)

/// --- END ADC12A Setting ---


/// --- BEGIN EEPROMC Setting ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define EEPROMC_T16_CH				(2)			/// Select T16 channel for EEPROMC 0 to 2

#define INTERRUPT_LEVEL_EEPROMC	(3)			/// Set EEPROMC interrupt level  0 to 7

/// --- END EEPROMC Setting ---


/// --- BEGIN I2C Setting ---

/**
 * Internal definition macro
 * Do not change.
 */

#define I2C_enable				(1)			/// --- Do not change. ---
#define I2C_disable				(0)			/// --- Do not change. ---
#define I2C_master				(1)			/// --- Do not change. ---
#define I2C_slave				(0)			/// --- Do not change. ---
#define I2C_IOSC				(0)			/// --- Do not change. ---
#define I2C_OSC1				(1)			/// --- Do not change. ---
#define I2C_OSC3				(2)			/// --- Do not change. ---
#define I2C_EXT					(3)			/// --- Do not change. ---
#define I2C_CLKDIV_1			(0)			/// --- Do not change. ---
#define I2C_CLKDIV_2			(1)			/// --- Do not change. ---
#define I2C_CLKDIV_4			(2)			/// --- Do not change. ---
#define I2C_CLKDIV_8			(3)			/// --- Do not change. ---
#define I2C_INIT(a, b, c, d)	(((I2C_##a) << 7) + ((I2C_##b) << 6) + ((I2C_##c) << 4) + (I2C_##d))	/// --- Do not change. ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_I2C	(3)			/// Set I2C interrupt level  0 to 7

#define I2C_CLK				(16000000)	/// I2C Clock source frequency(OSC3=16000000Hz)
										/// fCLK_I2C = I2C_CLK / [Clock division]
										/// Clock source and the clock division is set in the I2CCHx_INIT macro.
#define I2C_BSP				(400000)	/// Set I2C BPS[Hz] example (100000,400000)

#define I2C_SLAVE_ADDRESS	(0x2A)		/// I2C Address (Slave mode only.)

/**
 * I2C Setting
 * Please change the argument, if necessary.
 *  - 1st:Module activate(enable,disable)
 *  - 2nd:Mode(master,slave)
 *  - 3rd:Clock source(IOSC,OSC1,OSC3,EXT)
 *  - 4th:Clock division
 *          IOSC,OSC3(CLKDIV_xx:1,2,4,8)
 *          OSC1,EXT(CLKDIV_1)
 *
 * example.
 * #define I2CCH0_INIT I2C_INIT(enable, master, OSC3, CLKDIV_1)
 */

#ifdef C17_PE_I2C_MASTER
#define I2CCH0_INIT I2C_INIT(enable, master, OSC3, CLKDIV_1)
#endif
#ifdef C17_PE_I2C_SLAVE
#define I2CCH0_INIT I2C_INIT(enable, slave, OSC3, CLKDIV_1)
#endif

/// --- END I2C Setting ---


/// --- BEGIN LCD8B Setting ---

/**
 * Internal definition macro
 * Do not change.
 */

#define LCD_enable				(1)			/// --- Do not change. ---
#define LCD_disable				(0)			/// --- Do not change. ---
#define LCD_IOSC				(0)			/// --- Do not change. ---
#define LCD_OSC1				(1)			/// --- Do not change. ---
#define LCD_OSC3				(2)			/// --- Do not change. ---
#define LCD_EXT					(3)			/// --- Do not change. ---
#define LCD_CLKDIV_1			(0)			/// --- Do not change. ---
#define LCD_CLKDIV_4			(0)			/// --- Do not change. ---
#define LCD_CLKDIV_8			(1)			/// --- Do not change. ---
#define LCD_CLKDIV_16			(2)			/// --- Do not change. ---
#define LCD_CLKDIV_32			(3)			/// --- Do not change. ---
#define LCD_CLKDIV_64			(4)			/// --- Do not change. ---
#define LCD_CLKDIV_128			(5)			/// --- Do not change. ---
#define LCD_INIT(a, b, c)	(((LCD_##a) << 5) + ((LCD_##b) << 3) + (LCD_##c))	/// --- Do not change. ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_LCD8B	(3)			/// Set LCD8B interrupt level  0 to 7

/**
 * LCD8B Setting
 * Please change the argument, if necessary.
 *  - 1st:Module activate(enable,disable)
 *  - 2nd:Clock source(IOSC,OSC1,OSC3,EXT)
 *  - 3rd:Clock division
 *          IOSC,OSC3(CLKDIV_xx:4,8,16,32,64,128)
 *          OSC1,EXT(CLKDIV_1)
 *
 * example.
 * #define LCD8B_INIT LCD_INIT(enable, IOSC, CLKDIV_4)
 */

#define LCD8B_INIT LCD_INIT(enable, OSC1, CLKDIV_1)

/// --- END LCD8B Setting ---


/// --- BEGIN PORT Setting ---

/**
 * Internal definition macro
 * Do not change.
 */

#define PORT_enable				(1)			/// --- Do not change. ---
#define PORT_disable			(0)			/// --- Do not change. ---
#define PORT_input				(0)			/// --- Do not change. ---
#define PORT_output				(1)			/// --- Do not change. ---
#define PORT_chatta_enable		(1)			/// --- Do not change. ---
#define PORT_chatta_disable		(0)			/// --- Do not change. ---
#define PORT_none				(0)			/// --- Do not change. ---
#define PORT_pullup				(1)			/// --- Do not change. ---
#define PORT_pulldown			(2)			/// --- Do not change. ---
#define PORT_INIT(a, b, c, d)	(((PORT_##a) << 7) + ((PORT_##b) << 6) + ((PORT_##c) << 5) + (PORT_##d))	/// --- Do not change. ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_PORT	(3)			/// Set PORT interrupt level  0 to 7


/**
 * PORT Setting
 * Please change the argument, if necessary.
 *  - 1st:Module activate(enable,disable)
 *  - 2nd:Port direction(input,output)
 *  - 3rd:Chattering filter function(chatta_enable,chatta_disable)
 *  - 4th:Pull up,down control(none,pullup,pulldown)
 *
 * example.
 * #define PORT00_INIT PORT_INIT(enable,input,chatta_disable,pullup)
 */

/* P0X Setting */
#define PORT00_INIT PORT_INIT(disable, input,  chatta_disable, none)
#define PORT01_INIT PORT_INIT(enable,  output, chatta_disable, none)
#define PORT02_INIT PORT_INIT(enable,  input,  chatta_disable, pullup)
#define PORT03_INIT PORT_INIT(disable, input,  chatta_disable, none)
#define PORT04_INIT PORT_INIT(disable, input,  chatta_disable, none)
#define PORT05_INIT PORT_INIT(disable, input,  chatta_disable, none)
#define PORT06_INIT PORT_INIT(disable, input,  chatta_disable, none)
#define PORT07_INIT PORT_INIT(disable, input,  chatta_disable, none)

/* P1X Setting */
#define PORT10_INIT PORT_INIT(disable, input,  chatta_disable, none)
#define PORT11_INIT PORT_INIT(disable, input,  chatta_disable, none)
#define PORT12_INIT PORT_INIT(disable, input,  chatta_disable, none)
#define PORT13_INIT PORT_INIT(disable, input,  chatta_disable, none)
#define PORT14_INIT PORT_INIT(disable, input,  chatta_disable, none)
#define PORT15_INIT PORT_INIT(disable, input,  chatta_disable, none)

/* P2X Setting */
#define PORT20_INIT PORT_INIT(disable, input,  chatta_disable, none)
#define PORT21_INIT PORT_INIT(disable, input,  chatta_disable, none)

/* PDX Setting */
#define PORTD0_INIT PORT_INIT(disable, input,  chatta_disable, none)
#define PORTD1_INIT PORT_INIT(disable, input,  chatta_disable, none)
#define PORTD2_INIT PORT_INIT(disable, input,  chatta_disable, none)

/// --- END PORT Setting ---


/// --- BEGIN RTCLP Setting ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_RTCLP	(3)			/// Set RTCLP interrupt level  0 to 7


#define THEORETICAL_ENABLE		(1)			/// Theoretical Regulation enable = 1,disable = 0.
#define THEORETICAL_CYCLE_TIME	(4096)		/// Theoretical regulation execution cycle time n [sec]
#define THEORETICAL_TRIM		(0x43)		/// Correction rate : 0x43=(-58.2 ppm). 0x00 to 0x7f

/// --- END RTCLP Setting ---


/// --- BEGIN SNDA Setting ---

/**
 * Internal definition macro
 * Do not change.
 */
#define SNDA_enable				(1)			/// --- Do not change. ---
#define SNDA_disable			(0)			/// --- Do not change. ---
#define SNDA_IOSC				(0)			/// --- Do not change. ---
#define SNDA_OSC1				(1)			/// --- Do not change. ---
#define SNDA_OSC3				(2)			/// --- Do not change. ---
#define SNDA_EXT				(3)			/// --- Do not change. ---
#define SNDA_CLKDIV_1			(0)			/// --- Do not change. ---
#define SNDA_CLKDIV_4			(0)			/// --- Do not change. ---
#define SNDA_CLKDIV_8			(1)			/// --- Do not change. ---
#define SNDA_CLKDIV_16			(2)			/// --- Do not change. ---
#define SNDA_CLKDIV_32			(3)			/// --- Do not change. ---
#define SNDA_CLKDIV_64			(4)			/// --- Do not change. ---
#define SNDA_CLKDIV_128			(5)			/// --- Do not change. ---
#define SNDA_INIT(a, b, c)		(((SNDA_##a) << 5) + ((SNDA_##b) << 3) + (SNDA_##c))	/// --- Do not change. ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */
#define CLK_SNDA				(32768)		/// CLK_SNDA frequency[Hz]
											/// CLK_SNDA = Clock source / Clock division
											/// Clock source and the clock division is set in the SNDA_INIT macro.
											/// The CLK_SNDA frequency should be set to around 32,768 Hz.

#define INTERRUPT_LEVEL_SNDA	(3)			/// Set SNDA interrupt level  0 to 7

/**
 * SNDA Setting
 * Please change the argument, if necessary.
 *  - 1st:Module activate(enable,disable)
 *  - 2st:Clock source(IOSC,OSC1,OSC3,EXT)
 *  - 3nd:Clock division
 *          IOSC,OSC3(CLKDIV_xx:4,8,16,32,64,128)
 *          OSC1,EXT(CLKDIV_1)
 *
 * example.
 * #define SNDA_SET_INIT SNDA_INIT(enable, OSC1, CLKDIV_1)
 */

#define SNDA_SET_INIT SNDA_INIT(enable, OSC1, CLKDIV_1)

/// --- END SNDA Setting ---


/// --- BEGIN SPIA Setting ---

/**
 * Internal definition macro
 * Do not change.
 */

#define SPI_enable				(1)			/// --- Do not change. ---
#define SPI_disable				(0)			/// --- Do not change. ---
#define SPI_slave				(0)			/// --- Do not change. ---
#define SPI_master				(1)			/// --- Do not change. ---
#define SPI_pullUpDown_enable	(1)			/// --- Do not change. ---
#define SPI_pullUpDown_disable	(0)			/// --- Do not change. ---
#define SPI_mode0				(0)			/// --- Do not change. ---
#define SPI_mode1				(1)			/// --- Do not change. ---
#define SPI_mode2				(2)			/// --- Do not change. ---
#define SPI_mode3				(3)			/// --- Do not change. ---
#define SPI_msb					(0)			/// --- Do not change. ---
#define SPI_lsb					(1)			/// --- Do not change. ---
#define SPI_dataBit2			(1)			/// --- Do not change. ---
#define SPI_dataBit3			(2)			/// --- Do not change. ---
#define SPI_dataBit4			(3)			/// --- Do not change. ---
#define SPI_dataBit5			(4)			/// --- Do not change. ---
#define SPI_dataBit6			(5)			/// --- Do not change. ---
#define SPI_dataBit7			(6)			/// --- Do not change. ---
#define SPI_dataBit8			(7)			/// --- Do not change. ---
#define SPI_dataBit9			(8)			/// --- Do not change. ---
#define SPI_dataBit10			(9)			/// --- Do not change. ---
#define SPI_dataBit11			(10)		/// --- Do not change. ---
#define SPI_dataBit12			(11)		/// --- Do not change. ---
#define SPI_dataBit13			(12)		/// --- Do not change. ---
#define SPI_dataBit14			(13)		/// --- Do not change. ---
#define SPI_dataBit15			(14)		/// --- Do not change. ---
#define SPI_dataBit16			(15)		/// --- Do not change. ---
#define SPI_INIT(a, b, c, d, e, f)	(((SPI_##a) << 9) + ((SPI_##b) << 8) + ((SPI_##c) << 7) + ((SPI_##d) << 5) + ((SPI_##e) << 4) + (SPI_##f))	/// --- Do not change. ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_SPIA0	(0)			/// Set SPIA CH.0 interrupt level  0 to 7
#define INTERRUPT_LEVEL_SPIA1	(0)			/// Set SPIA CH.1 interrupt level  0 to 7

/**
 * SPI Setting
 * Please change the argument, if necessary.
 *  - 1st:Module activate(enable,disable)
 *  - 2nd:Mode(slave,master)
 *  - 3rd:Pull up,down control(pullUpDown_enable,pullUpDown_disable)
 *  - 4th:Clock phase,Polarity(mode0,mode1,mode2,mode3)
 *  - 5th:Data format(lsb,msb)
 *  - 6th:Bit length of transfer data(dataBitxx:2,3,4,5,6,7,8,9,10,11,12,13,14,15,16)
 *
 * example.
 * #define SPICH0_INIT SPI_INIT(enable, master, pullUpDown_enable, mode0, msb, dataBit8)
 */

#ifdef C17_PE_SPIA_MASTER
#define SPICH0_INIT SPI_INIT(enable, master, pullUpDown_disable, mode3, msb, dataBit8)
#define SPICH1_INIT SPI_INIT(disable, master, pullUpDown_disable, mode3, msb, dataBit8)
#endif
#ifdef C17_PE_SPIA_SLAVE
#define SPICH0_INIT SPI_INIT(enable, slave, pullUpDown_disable, mode3, msb, dataBit8)
#define SPICH1_INIT SPI_INIT(disable, master, pullUpDown_disable, mode3, msb, dataBit8)
#endif

/// --- END SPIA Setting ---


/// --- BEGIN SVD3 Setting ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_SVD	(3)			/// Set SVD interrupt level  0 to 7

/// --- END SVD3 Setting ---


/// --- BEGIN T16 Setting ---

/**
 * Internal definition macro
 * Do not change.
 */

#define T16_enable				(1)			/// --- Do not change. ---
#define T16_disable				(0)			/// --- Do not change. ---
#define T16_IOSC				(0)			/// --- Do not change. ---
#define T16_OSC1				(1)			/// --- Do not change. ---
#define T16_OSC3				(2)			/// --- Do not change. ---
#define T16_EXT					(3)			/// --- Do not change. ---
#define T16_repeat				(0)			/// --- Do not change. ---
#define T16_oneshot				(1)			/// --- Do not change. ---
#define T16_CLKDIV_1			(0)			/// --- Do not change. ---
#define T16_CLKDIV_2			(1)			/// --- Do not change. ---
#define T16_CLKDIV_4			(2)			/// --- Do not change. ---
#define T16_CLKDIV_8			(3)			/// --- Do not change. ---
#define T16_CLKDIV_16			(4)			/// --- Do not change. ---
#define T16_CLKDIV_32			(5)			/// --- Do not change. ---
#define T16_CLKDIV_64			(6)			/// --- Do not change. ---
#define T16_CLKDIV_128			(7)			/// --- Do not change. ---
#define T16_CLKDIV_256			(8)			/// --- Do not change. ---
#define T16_CLKDIV_512			(9)			/// --- Do not change. ---
#define T16_CLKDIV_1024			(10)		/// --- Do not change. ---
#define T16_CLKDIV_2048			(11)		/// --- Do not change. ---
#define T16_CLKDIV_4096			(12)		/// --- Do not change. ---
#define T16_CLKDIV_8192			(13)		/// --- Do not change. ---
#define T16_CLKDIV_16384		(14)		/// --- Do not change. ---
#define T16_CLKDIV_32768		(15)		/// --- Do not change. ---
#define T16_INIT(a, b, c, d)	(((T16_##a) << 7) + ((T16_##b) << 5) + ((T16_##d) << 4) + (T16_##c))	/// --- Do not change. ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_T16_0	(3)			/// Set T16 CH.0 interrupt level  0 to 7
#define INTERRUPT_LEVEL_T16_1	(3)			/// Set T16 CH.1 interrupt level  0 to 7
#define INTERRUPT_LEVEL_T16_2	(3)			/// Set T16 CH.2 interrupt level  0 to 7
#define INTERRUPT_LEVEL_T16_3	(3)			/// Set T16 CH.3 interrupt level  0 to 7

/**
 * T16 Setting
 * Please change the argument, if necessary.
 *  - 1st:Module activate(enable,disable)
 *  - 2nd:Clock source(IOSC,OSC1,OSC3,EXT)
 *  - 3rd:Clock division
 *          IOSC,OSC3(CLKDIV_xx:1,2,4,8,16,32,64,128,256,512,1024,2048,4096,8192,16384,32768)
 *          OSC1(CLKDIV_xx:1,2,4,8,16,32,64,128,256)
 *          EXT(CLKDIV_1)
 *  - 4th:Mode(repeat,oneshot)
 *
 * example.
 * #define T16CH0_INIT T16_INIT(enable, IOSC, CLKDIV_32, oneshot)
 */

#define T16CH0_INIT T16_INIT(enable,  IOSC, CLKDIV_32, repeat)
#define T16CH1_INIT T16_INIT(disable, IOSC, CLKDIV_1,  repeat)
#define T16CH2_INIT T16_INIT(disable, IOSC, CLKDIV_1,  repeat)

/// --- END T16 Setting ---


/// --- BEGIN T16B Setting ---

/**
 * Internal definition macro
 * Do not change.
 */

#define T16B_enable				(1)			/// --- Do not change. ---
#define T16B_disable			(0)			/// --- Do not change. ---
#define T16B_IOSC				(0)			/// --- Do not change. ---
#define T16B_OSC1				(1)			/// --- Do not change. ---
#define T16B_OSC3				(2)			/// --- Do not change. ---
#define T16B_EXT				(3)			/// --- Do not change. ---
#define T16B_EXCL0				(4)			/// --- Do not change. ---
#define T16B_EXCL1				(5)			/// --- Do not change. ---
#define T16B_EXCL0INV			(6)			/// --- Do not change. ---
#define T16B_EXCL1INV			(7)			/// --- Do not change. ---
#define T16B_up					(0)			/// --- Do not change. ---
#define T16B_down				(1)			/// --- Do not change. ---
#define T16B_updown				(2)			/// --- Do not change. ---
#define T16B_repeat				(0)			/// --- Do not change. ---
#define T16B_oneshot			(1)			/// --- Do not change. ---
#define T16B_CLKDIV_1			(0)			/// --- Do not change. ---
#define T16B_CLKDIV_2			(1)			/// --- Do not change. ---
#define T16B_CLKDIV_4			(2)			/// --- Do not change. ---
#define T16B_CLKDIV_8			(3)			/// --- Do not change. ---
#define T16B_CLKDIV_16			(4)			/// --- Do not change. ---
#define T16B_CLKDIV_32			(5)			/// --- Do not change. ---
#define T16B_CLKDIV_64			(6)			/// --- Do not change. ---
#define T16B_CLKDIV_128			(7)			/// --- Do not change. ---
#define T16B_CLKDIV_256			(8)			/// --- Do not change. ---
#define T16B_CLKDIV_512			(9)			/// --- Do not change. ---
#define T16B_CLKDIV_1024		(10)		/// --- Do not change. ---
#define T16B_CLKDIV_2048		(11)		/// --- Do not change. ---
#define T16B_CLKDIV_4096		(12)		/// --- Do not change. ---
#define T16B_CLKDIV_8192		(13)		/// --- Do not change. ---
#define T16B_CLKDIV_16384		(14)		/// --- Do not change. ---
#define T16B_CLKDIV_32768		(15)		/// --- Do not change. ---
#define T16B_INIT(a, b, c, d, e)(((T16B_##a) << 10) + ((T16B_##b) << 7) + ((T16B_##d) << 5) + ((T16B_##e) << 4) + (T16B_##c))	/// --- Do not change. ---


/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_T16B_0	(3)			/// Set T16B CH.0 interrupt level  0 to 7


/**
 * T16B Setting
 * Please change the argument, if necessary.
 *  - 1st:Module activate(enable,disable)
 *  - 2nd:Clock source(IOSC,OSC1,OSC3,EXT,EXCL0,EXCL1,EXCL0INV,EXCL1INV)
 *  - 3rd:Clock division
 *          IOSC,OSC3(CLKDIV_xx:1,2,4,8,16,32,64,128,256,512,1024,2048,4096,8192,16384,32768)
 *          OSC1(CLKDIV_xx:1,2,4,8,16,32,64,128,256)
 *          EXT,EXCL0,EXCL1,EXCL0INV,EXCL1INV(CLKDIV_1)
 *  - 4th:Count mode(up,down,updown)
 *  - 5th:Mode(repeat,oneshot)
 *
 * example.
 * #define T16BCH0_INIT T16B_INIT(enable, IOSC, CLKDIV_32, up, repeat)
 */

#define T16BCH0_INIT T16B_INIT(enable, OSC3, CLKDIV_32, up, repeat)

/// --- END T16B Setting ---


/// --- BEGIN UART3 Setting ---

/**
 * Internal definition macro
 * Do not change.
 */

#define UART_IOSC				(0)			/// --- Do not change. ---
#define UART_OSC1				(1)			/// --- Do not change. ---
#define UART_OSC3				(2)			/// --- Do not change. ---
#define UART_EXT				(3)			/// --- Do not change. ---
#define UART_CLKDIV_1			(0)			/// --- Do not change. ---
#define UART_CLKDIV_2			(1)			/// --- Do not change. ---
#define UART_CLKDIV_4			(2)			/// --- Do not change. ---
#define UART_CLKDIV_8			(3)			/// --- Do not change. ---
#define UART_parity_none		(0)			/// --- Do not change. ---
#define UART_parity_odd			(1)			/// --- Do not change. ---
#define UART_parity_even		(2)			/// --- Do not change. ---
#define UART_stop_2				(1)			/// --- Do not change. ---
#define UART_stop_1				(0)			/// --- Do not change. ---
#define UART_data_8				(1)			/// --- Do not change. ---
#define UART_data_7				(0)			/// --- Do not change. ---
#define UART_INIT(a, b, c, d, e)	(((UART_##a) << 6) + ((UART_##b) << 4) + ((UART_##c) << 2) + ((UART_##d) << 1) + (UART_##e))	/// --- Do not change. ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */
#define UART_CLOCK				(700000)		/// Uart Clock source frequency(IOSC=700000Hz)
												/// CLK_UART3 = UART_CLOCK / [Clock division]
												/// Clock source and the clock division is set in the UARTCHx_INIT macro.
#define UART_BSP				(9600)			/// Set UART BPS example (9600,19200,.,115200,.)


#define INTERRUPT_LEVEL_UART	(3)				/// Set UART interrupt level  0 to 7

#define IOSC_CALIBRATION_ENABLE	(1)				/**
												 * calibration enable = 1,calibration disable = 0
												 * If the UART clock source of the IOSC,
												 * to adjust the baud rate using the other clock(OSC3 or OSC1).
												 */

#define IOSC_CALIBRATION_CLOCK	(32768)			/// clock source frequency(ex. OSC3 = 4000000Hz, OSC1 = 32768Hz)

/**
 * UART Setting
 * Please change the argument, if necessary.
 *  - 1st:Clock source(IOSC,OSC1,OSC3,EXT)
 *  - 2nd:Clock division
 *          IOSC,OSC3(CLKDIV_xx:1,2,4,8)
 *          OSC1,EXT(CLKDIV_1)
 *  - 3rd:Parity mode(parity_none,parity_odd,parity_even)
 *  - 4th:Stop bit length(stop_2,stop_1)
 *  - 5th:Data bit length(data_7,data_8)
 *
 * example.
 * #define UARTCH0_INIT UART_INIT(IOSC,CLKDIV_1,parity_none,stop_1,data_8)
 */

#define UARTCH0_INIT UART_INIT(IOSC, CLKDIV_1, parity_none, stop_1, data_8)

/// --- END UART3 Setting ---


#endif /* C17_INIT_CONFIG_H_ */

