/************************************************************************//**
 *
 * @file    c17_t16.c
 *
 * @brief   This is 16-bit  Timers driver header file.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2019. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *          - 01 Oct. 2017    1.10
 *              - Change source code.
 *          - 01 Jun. 2018    1.20
 *              - Change source code.
 *          - 19 Jun. 2019    1.30
 *              - Change source code.
 *
 ***************************************************************************/
#include "crt0.h"
#include "c17_misc.h"
#include "c17_t16.h"
#include "c17_init_config.h"

#if defined(C17_PE_T16)

/* --- interrupt handler (GNU17v3 Only) --- */
#ifdef CRT0_LINKED
#if defined(C17_MCUSEL_M01)
#if defined(C17_PE_SOFTREMC)
	#if (SOFTREMC_CARRIER_TIMER_CH0 == 0)

	#elif (SOFTREMC_CARRIER_TIMER_CH1 == 0)

	#elif (SOFTREMC_DATA_TIMER_CH0 == 0)

	#elif (SOFTREMC_DATA_TIMER_CH1 == 0)

	#else
		C17_INTERRUPT_HANDLER(_vector08_handler, c17intT16Ch0);		// T16 Ch.0 interrupt
	#endif
#else
		C17_INTERRUPT_HANDLER(_vector08_handler, c17intT16Ch0);		// T16 Ch.0 interrupt
#endif

#if defined(C17_PE_SOFTREMC)
	#if (SOFTREMC_CARRIER_TIMER_CH0 == 1)

	#elif (SOFTREMC_CARRIER_TIMER_CH1 == 1)

	#elif (SOFTREMC_DATA_TIMER_CH0 == 1)

	#elif (SOFTREMC_DATA_TIMER_CH1 == 1)

	#else
		C17_INTERRUPT_HANDLER(_vector10_handler, c17intT16Ch1);		// T16 Ch.1 interrupt
	#endif
#else
	C17_INTERRUPT_HANDLER(_vector10_handler, c17intT16Ch1);			// T16 Ch.1 interrupt
#endif

#if defined(C17_PE_SOFTREMC)
	#if (SOFTREMC_CARRIER_TIMER_CH0 == 2)

	#elif (SOFTREMC_CARRIER_TIMER_CH1 == 2)

	#elif (SOFTREMC_DATA_TIMER_CH0 == 2)

	#elif (SOFTREMC_DATA_TIMER_CH1 == 2)

	#else
		C17_INTERRUPT_HANDLER(_vector13_handler, c17intT16Ch2);		// T16 Ch.2 interrupt
	#endif
#else
	C17_INTERRUPT_HANDLER(_vector13_handler, c17intT16Ch2);			// T16 Ch.2 interrupt
#endif

#if defined(C17_PE_SOFTREMC)
	#if (SOFTREMC_CARRIER_TIMER_CH0 == 3)

	#elif (SOFTREMC_CARRIER_TIMER_CH1 == 3)

	#elif (SOFTREMC_DATA_TIMER_CH0 == 3)

	#elif (SOFTREMC_DATA_TIMER_CH1 == 3)

	#else
		C17_INTERRUPT_HANDLER(_vector14_handler, c17intT16Ch3);		// T16 Ch.3 interrupt
	#endif
#else
	C17_INTERRUPT_HANDLER(_vector14_handler, c17intT16Ch3);			// T16 Ch.3 interrupt
#endif

#if defined(C17_PE_SOFTREMC)
	#if (SOFTREMC_CARRIER_TIMER_CH0 == 4)

	#elif (SOFTREMC_CARRIER_TIMER_CH1 == 4)

	#elif (SOFTREMC_DATA_TIMER_CH0 == 4)

	#elif (SOFTREMC_DATA_TIMER_CH1 == 4)

	#else
		C17_INTERRUPT_HANDLER(_vector15_handler, c17intT16Ch4);		// T16 Ch.4 interrupt
	#endif
#else
	C17_INTERRUPT_HANDLER(_vector15_handler, c17intT16Ch4);			// T16 Ch.4 interrupt
#endif

#endif
#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M12) || defined(C17_MCUSEL_M13) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13) || \
	defined(C17_MCUSEL_W14) || defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W15) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_589) || \
	defined(C17_MCUSEL_M10) || \
	defined(C17_MCUSEL_M40) || \
	defined(C17_MCUSEL_F63)


#if defined(C17_PE_SOFTREMC)
	#if (SOFTREMC_DATA_TIMER	==	SOFTREMC_t16) && (SOFTREMC_DATA_TIMER_CH0 == 0)

	#elif (SOFTREMC_DATA_TIMER	==	SOFTREMC_t16) && (SOFTREMC_DATA_TIMER_CH1 == 0)

	#else
		C17_INTERRUPT_HANDLER(_vector09_handler, c17intT16Ch0);		// T16 Ch.0 interrupt
	#endif
#else
	C17_INTERRUPT_HANDLER(_vector09_handler, c17intT16Ch0);			// T16 Ch.0 interrupt
#endif
#if defined(C17_PE_SOFTREMC)
	#if (SOFTREMC_DATA_TIMER	==	SOFTREMC_t16) && (SOFTREMC_DATA_TIMER_CH0 == 1)

	#elif (SOFTREMC_DATA_TIMER	==	SOFTREMC_t16) && (SOFTREMC_DATA_TIMER_CH1 == 1)

	#else
		C17_INTERRUPT_HANDLER(_vector11_handler, c17intT16Ch1);		// T16 Ch.1 interrupt
	#endif
#else
	C17_INTERRUPT_HANDLER(_vector11_handler, c17intT16Ch1);			// T16 Ch.1 interrupt
#endif

#endif
#if defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M12) || defined(C17_MCUSEL_M13) || \
	defined(C17_MCUSEL_M10)

#if defined(C17_PE_SOFTREMC)
	#if (SOFTREMC_DATA_TIMER	==	SOFTREMC_t16) && (SOFTREMC_DATA_TIMER_CH0 == 2)

	#elif (SOFTREMC_DATA_TIMER	==	SOFTREMC_t16) && (SOFTREMC_DATA_TIMER_CH1 == 2)

	#else
		C17_INTERRUPT_HANDLER(_vector15_handler, c17intT16Ch2);		// T16 Ch.2 interrupt
	#endif
#else
		C17_INTERRUPT_HANDLER(_vector15_handler, c17intT16Ch2);		// T16 Ch.2 interrupt
#endif


#if defined(C17_PE_SOFTREMC)
	#if (SOFTREMC_DATA_TIMER	==	SOFTREMC_t16) && (SOFTREMC_DATA_TIMER_CH0 == 3)

	#elif (SOFTREMC_DATA_TIMER	==	SOFTREMC_t16) && (SOFTREMC_DATA_TIMER_CH1 == 3)

	#else
		C17_INTERRUPT_HANDLER(_vector16_handler, c17intT16Ch3);		// T16 Ch.3 interrupt
	#endif
#else
	C17_INTERRUPT_HANDLER(_vector16_handler, c17intT16Ch3);		// T16 Ch.3 interrupt
#endif


#endif
#if defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36)
C17_INTERRUPT_HANDLER(_vector18_handler, c17intT16Ch2);		// T16 Ch.2 interrupt
C17_INTERRUPT_HANDLER(_vector25_handler, c17intT16Ch3);		// T16 Ch.3 interrupt
#endif
#if defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_M40)
C17_INTERRUPT_HANDLER(_vector22_handler, c17intT16Ch2);		// T16 Ch.2 interrupt
C17_INTERRUPT_HANDLER(_vector24_handler, c17intT16Ch3);		// T16 Ch.3 interrupt
#endif
#if defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13) || \
	defined(C17_MCUSEL_W15)


#if defined(C17_PE_SOFTREMC)
	#if (SOFTREMC_DATA_TIMER	==	SOFTREMC_t16) && (SOFTREMC_DATA_TIMER_CH0 == 2)

	#elif (SOFTREMC_DATA_TIMER	==	SOFTREMC_t16) && (SOFTREMC_DATA_TIMER_CH1 == 2)

	#else
		C17_INTERRUPT_HANDLER(_vector17_handler, c17intT16Ch2);		// T16 Ch.2 interrupt
	#endif
#else
		C17_INTERRUPT_HANDLER(_vector17_handler, c17intT16Ch2);		// T16 Ch.2 interrupt
#endif



#endif
#if defined(C17_MCUSEL_W14) || defined(C17_MCUSEL_W16)
C17_INTERRUPT_HANDLER(_vector22_handler, c17intT16Ch2);		// T16 Ch.2 interrupt
#endif
#if defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_589)
C17_INTERRUPT_HANDLER(_vector24_handler, c17intT16Ch3);		// T16 Ch.3 interrupt
C17_INTERRUPT_HANDLER(_vector26_handler, c17intT16Ch4);		// T16 Ch.4 interrupt
#endif
#if defined(C17_MCUSEL_589)
C17_INTERRUPT_HANDLER(_vector18_handler, c17intT16Ch5);		// T16 Ch.5 interrupt
C17_INTERRUPT_HANDLER(_vector20_handler, c17intT16Ch2);		// T16 Ch.2 interrupt
#endif
#if defined(C17_MCUSEL_F63)
C17_INTERRUPT_HANDLER(_vector18_handler, c17intT16Ch2);		// T16 Ch.2 interrupt
C17_INTERRUPT_HANDLER(_vector22_handler, c17intT16Ch3);		// T16 Ch.3 interrupt
#endif

#if defined(C17_MCUSEL_M10)

#if defined(C17_PE_SOFTREMC)
	#if (SOFTREMC_DATA_TIMER	==	SOFTREMC_t16) && (SOFTREMC_DATA_TIMER_CH0 == 4)

	#elif (SOFTREMC_DATA_TIMER	==	SOFTREMC_t16) && (SOFTREMC_DATA_TIMER_CH1 == 4)

	#else
		C17_INTERRUPT_HANDLER(_vector17_handler, c17intT16Ch4);		// T16 Ch.4 interrupt
	#endif
#else
	C17_INTERRUPT_HANDLER(_vector17_handler, c17intT16Ch4);		// T16 Ch.4 interrupt
#endif

#endif

#endif /* CRT0_LINKED */

/* --- macro definition --- */
#if defined(C17_MCUSEL_589)
#define CH_MAX_COUNT	6
#endif

#if defined(C17_MCUSEL_M01) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_M10)
#define CH_MAX_COUNT	5
#endif

#if defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M12) || defined(C17_MCUSEL_M13) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_M40) || \
	defined(C17_MCUSEL_F63)
#define CH_MAX_COUNT	4
#endif

#if defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13) || \
	defined(C17_MCUSEL_W14) || \
	defined(C17_MCUSEL_W15)
#define CH_MAX_COUNT	3
#endif

#if defined(C17_MCUSEL_W22)
#define CH_MAX_COUNT	2
#endif

/* --- static const variable --- */
#if defined(C17_MCUSEL_589)
volatile T16_NCLK_REG* const t16_nclk_table[CH_MAX_COUNT] = {(T16_NCLK_REG *)&T16_0CLK,(T16_NCLK_REG *)&T16_1CLK,(T16_NCLK_REG *)&T16_2CLK,(T16_NCLK_REG *)&T16_3CLK,(T16_NCLK_REG *)&T16_4CLK,(T16_NCLK_REG *)&T16_5CLK};
volatile T16_NMOD_REG* const t16_nmod_table[CH_MAX_COUNT] = {(T16_NMOD_REG *)&T16_0MOD,(T16_NMOD_REG *)&T16_1MOD,(T16_NMOD_REG *)&T16_2MOD,(T16_NMOD_REG *)&T16_3MOD,(T16_NMOD_REG *)&T16_4MOD,(T16_NMOD_REG *)&T16_5MOD};
volatile T16_NCTL_REG* const t16_nctl_table[CH_MAX_COUNT] = {(T16_NCTL_REG *)&T16_0CTL,(T16_NCTL_REG *)&T16_1CTL,(T16_NCTL_REG *)&T16_2CTL,(T16_NCTL_REG *)&T16_3CTL,(T16_NCTL_REG *)&T16_4CTL,(T16_NCTL_REG *)&T16_5CTL};
volatile T16_NTR_REG* const t16_ntr_table[CH_MAX_COUNT] = {(T16_NTR_REG *)&T16_0TR,(T16_NTR_REG *)&T16_1TR,(T16_NTR_REG *)&T16_2TR,(T16_NTR_REG *)&T16_3TR,(T16_NTR_REG *)&T16_4TR,(T16_NTR_REG *)&T16_5TR};
volatile T16_NTC_REG* const t16_ntc_table[CH_MAX_COUNT] = {(T16_NTC_REG *)&T16_0TC,(T16_NTC_REG *)&T16_1TC,(T16_NTC_REG *)&T16_2TC,(T16_NTC_REG *)&T16_3TC,(T16_NTC_REG *)&T16_4TC,(T16_NTC_REG *)&T16_5TC};
volatile T16_NINTF_REG* const t16_intf_table[CH_MAX_COUNT] = {(T16_NINTF_REG *)&T16_0INTF,(T16_NINTF_REG *)&T16_1INTF,(T16_NINTF_REG *)&T16_2INTF,(T16_NINTF_REG *)&T16_3INTF,(T16_NINTF_REG *)&T16_4INTF,(T16_NINTF_REG *)&T16_5INTF};
volatile T16_NINTE_REG* const t16_inte_table[CH_MAX_COUNT] = {(T16_NINTE_REG *)&T16_0INTE,(T16_NINTE_REG *)&T16_1INTE,(T16_NINTE_REG *)&T16_2INTE,(T16_NINTE_REG *)&T16_3INTE,(T16_NINTE_REG *)&T16_4INTE,(T16_NINTE_REG *)&T16_5INTE};
#endif
#if defined(C17_MCUSEL_M01) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_M10)
volatile T16_NCLK_REG* const t16_nclk_table[CH_MAX_COUNT] = {(T16_NCLK_REG *)&T16_0CLK,(T16_NCLK_REG *)&T16_1CLK,(T16_NCLK_REG *)&T16_2CLK,(T16_NCLK_REG *)&T16_3CLK,(T16_NCLK_REG *)&T16_4CLK};
volatile T16_NMOD_REG* const t16_nmod_table[CH_MAX_COUNT] = {(T16_NMOD_REG *)&T16_0MOD,(T16_NMOD_REG *)&T16_1MOD,(T16_NMOD_REG *)&T16_2MOD,(T16_NMOD_REG *)&T16_3MOD,(T16_NMOD_REG *)&T16_4MOD};
volatile T16_NCTL_REG* const t16_nctl_table[CH_MAX_COUNT] = {(T16_NCTL_REG *)&T16_0CTL,(T16_NCTL_REG *)&T16_1CTL,(T16_NCTL_REG *)&T16_2CTL,(T16_NCTL_REG *)&T16_3CTL,(T16_NCTL_REG *)&T16_4CTL};
volatile T16_NTR_REG* const t16_ntr_table[CH_MAX_COUNT] = {(T16_NTR_REG *)&T16_0TR,(T16_NTR_REG *)&T16_1TR,(T16_NTR_REG *)&T16_2TR,(T16_NTR_REG *)&T16_3TR,(T16_NTR_REG *)&T16_4TR};
volatile T16_NTC_REG* const t16_ntc_table[CH_MAX_COUNT] = {(T16_NTC_REG *)&T16_0TC,(T16_NTC_REG *)&T16_1TC,(T16_NTC_REG *)&T16_2TC,(T16_NTC_REG *)&T16_3TC,(T16_NTC_REG *)&T16_4TC};
volatile T16_NINTF_REG* const t16_intf_table[CH_MAX_COUNT] = {(T16_NINTF_REG *)&T16_0INTF,(T16_NINTF_REG *)&T16_1INTF,(T16_NINTF_REG *)&T16_2INTF,(T16_NINTF_REG *)&T16_3INTF,(T16_NINTF_REG *)&T16_4INTF};
volatile T16_NINTE_REG* const t16_inte_table[CH_MAX_COUNT] = {(T16_NINTE_REG *)&T16_0INTE,(T16_NINTE_REG *)&T16_1INTE,(T16_NINTE_REG *)&T16_2INTE,(T16_NINTE_REG *)&T16_3INTE,(T16_NINTE_REG *)&T16_4INTE};
#endif
#if defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M12) || defined(C17_MCUSEL_M13) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_M40) || \
	defined(C17_MCUSEL_F63)
volatile T16_NCLK_REG* const t16_nclk_table[CH_MAX_COUNT] = {(T16_NCLK_REG *)&T16_0CLK,(T16_NCLK_REG *)&T16_1CLK,(T16_NCLK_REG *)&T16_2CLK,(T16_NCLK_REG *)&T16_3CLK};
volatile T16_NMOD_REG* const t16_nmod_table[CH_MAX_COUNT] = {(T16_NMOD_REG *)&T16_0MOD,(T16_NMOD_REG *)&T16_1MOD,(T16_NMOD_REG *)&T16_2MOD,(T16_NMOD_REG *)&T16_3MOD};
volatile T16_NCTL_REG* const t16_nctl_table[CH_MAX_COUNT] = {(T16_NCTL_REG *)&T16_0CTL,(T16_NCTL_REG *)&T16_1CTL,(T16_NCTL_REG *)&T16_2CTL,(T16_NCTL_REG *)&T16_3CTL};
volatile T16_NTR_REG* const t16_ntr_table[CH_MAX_COUNT] = {(T16_NTR_REG *)&T16_0TR,(T16_NTR_REG *)&T16_1TR,(T16_NTR_REG *)&T16_2TR,(T16_NTR_REG *)&T16_3TR};
volatile T16_NTC_REG* const t16_ntc_table[CH_MAX_COUNT] = {(T16_NTC_REG *)&T16_0TC,(T16_NTC_REG *)&T16_1TC,(T16_NTC_REG *)&T16_2TC,(T16_NTC_REG *)&T16_3TC};
volatile T16_NINTF_REG* const t16_intf_table[CH_MAX_COUNT] = {(T16_NINTF_REG *)&T16_0INTF,(T16_NINTF_REG *)&T16_1INTF,(T16_NINTF_REG *)&T16_2INTF,(T16_NINTF_REG *)&T16_3INTF};
volatile T16_NINTE_REG* const t16_inte_table[CH_MAX_COUNT] = {(T16_NINTE_REG *)&T16_0INTE,(T16_NINTE_REG *)&T16_1INTE,(T16_NINTE_REG *)&T16_2INTE,(T16_NINTE_REG *)&T16_3INTE};
#endif
#if defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13) || \
	defined(C17_MCUSEL_W14) || \
	defined(C17_MCUSEL_W15)
volatile T16_NCLK_REG* const t16_nclk_table[CH_MAX_COUNT] = {(T16_NCLK_REG *)&T16_0CLK,(T16_NCLK_REG *)&T16_1CLK,(T16_NCLK_REG *)&T16_2CLK};
volatile T16_NMOD_REG* const t16_nmod_table[CH_MAX_COUNT] = {(T16_NMOD_REG *)&T16_0MOD,(T16_NMOD_REG *)&T16_1MOD,(T16_NMOD_REG *)&T16_2MOD};
volatile T16_NCTL_REG* const t16_nctl_table[CH_MAX_COUNT] = {(T16_NCTL_REG *)&T16_0CTL,(T16_NCTL_REG *)&T16_1CTL,(T16_NCTL_REG *)&T16_2CTL};
volatile T16_NTR_REG* const t16_ntr_table[CH_MAX_COUNT] = {(T16_NTR_REG *)&T16_0TR,(T16_NTR_REG *)&T16_1TR,(T16_NTR_REG *)&T16_2TR};
volatile T16_NTC_REG* const t16_ntc_table[CH_MAX_COUNT] = {(T16_NTC_REG *)&T16_0TC,(T16_NTC_REG *)&T16_1TC,(T16_NTC_REG *)&T16_2TC};
volatile T16_NINTF_REG* const t16_intf_table[CH_MAX_COUNT] = {(T16_NINTF_REG *)&T16_0INTF,(T16_NINTF_REG *)&T16_1INTF,(T16_NINTF_REG *)&T16_2INTF};
volatile T16_NINTE_REG* const t16_inte_table[CH_MAX_COUNT] = {(T16_NINTE_REG *)&T16_0INTE,(T16_NINTE_REG *)&T16_1INTE,(T16_NINTE_REG *)&T16_2INTE};
#endif
#if defined(C17_MCUSEL_W22)
volatile T16_NCLK_REG* const t16_nclk_table[CH_MAX_COUNT] = {(T16_NCLK_REG *)&T16_0CLK,(T16_NCLK_REG *)&T16_1CLK};
volatile T16_NMOD_REG* const t16_nmod_table[CH_MAX_COUNT] = {(T16_NMOD_REG *)&T16_0MOD,(T16_NMOD_REG *)&T16_1MOD};
volatile T16_NCTL_REG* const t16_nctl_table[CH_MAX_COUNT] = {(T16_NCTL_REG *)&T16_0CTL,(T16_NCTL_REG *)&T16_1CTL};
volatile T16_NTR_REG* const t16_ntr_table[CH_MAX_COUNT] = {(T16_NTR_REG *)&T16_0TR,(T16_NTR_REG *)&T16_1TR};
volatile T16_NTC_REG* const t16_ntc_table[CH_MAX_COUNT] = {(T16_NTC_REG *)&T16_0TC,(T16_NTC_REG *)&T16_1TC};
volatile T16_NINTF_REG* const t16_intf_table[CH_MAX_COUNT] = {(T16_NINTF_REG *)&T16_0INTF,(T16_NINTF_REG *)&T16_1INTF};
volatile T16_NINTE_REG* const t16_inte_table[CH_MAX_COUNT] = {(T16_NINTE_REG *)&T16_0INTE,(T16_NINTE_REG *)&T16_1INTE};
#endif

/* --- global variable --- */
// Interrupt counter.
/**
 * @todo c17t16Ch0IntCount = Interruption counter.
 */
volatile unsigned int c17t16Ch0IntCount = 0;	///< Interruption counter.

/************************************************************************//**
 * @brief   Initialization of the T16 Register.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17initT16(void)
{
	/// Disable T16 Ch.N Timer.
	c17disableT16(0);
	c17disableT16(1);
#if defined(C17_MCUSEL_M01) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M12) || defined(C17_MCUSEL_M13) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13) || \
	defined(C17_MCUSEL_W14) || defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W15) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_589) || \
	defined(C17_MCUSEL_M10) || \
	defined(C17_MCUSEL_M40) || \
	defined(C17_MCUSEL_F63)
	c17disableT16(2);
#endif
#if defined(C17_MCUSEL_M01) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M12) || defined(C17_MCUSEL_M13) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_589) || \
	defined(C17_MCUSEL_M10) || \
	defined(C17_MCUSEL_M40)
	c17disableT16(3);
#endif
#if defined(C17_MCUSEL_M01) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_589) || \
	defined(C17_MCUSEL_M10)
	c17disableT16(4);
#endif
#if defined(C17_MCUSEL_589)
	c17disableT16(5);
#endif

	/// T16 CH 0 Setting
	if((T16CH0_INIT & 0x80) == 0x80)
	{
		/// Initialize T16 timer.
		c17setT16(0, (T16CH0_INIT & 0x60)>>5, (T16CH0_INIT & 0x0F), (T16CH0_INIT & 0x10)>>4);

		/// Initialize the interrupt.
		ILVT16_0 = INTERRUPT_LEVEL_T16_0;				/// - Set interrupt level.
	}

	/// T16 CH 1 Setting
	if((T16CH1_INIT & 0x80) == 0x80)
	{
		/// Initialize T16 timer.
		c17setT16(1, (T16CH1_INIT & 0x60)>>5, (T16CH1_INIT & 0x0F), (T16CH1_INIT & 0x10)>>4);

		/// Initialize the interrupt.
		ILVT16_1 = INTERRUPT_LEVEL_T16_1;				/// - Set interrupt level.
	}

#if defined(C17_MCUSEL_M01) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M12) || defined(C17_MCUSEL_M13) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13) || \
	defined(C17_MCUSEL_W14) || defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W15) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_589) || \
	defined(C17_MCUSEL_M10) || \
	defined(C17_MCUSEL_M40) || \
	defined(C17_MCUSEL_F63)
	/// T16 CH 2 Setting
	if((T16CH2_INIT & 0x80) == 0x80)
	{
		/// Initialize T16 timer.
		c17setT16(2, (T16CH2_INIT & 0x60)>>5, (T16CH2_INIT & 0x0F), (T16CH2_INIT & 0x10)>>4);

		/// Initialize the interrupt.
		ILVT16_2 = INTERRUPT_LEVEL_T16_2;				/// - Set interrupt level.
	}
#endif

#if defined(C17_MCUSEL_M01) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M12) || defined(C17_MCUSEL_M13) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_589) || \
	defined(C17_MCUSEL_M10) || \
	defined(C17_MCUSEL_M40)
	/// T16 CH 3 Setting
	if((T16CH3_INIT & 0x80) == 0x80)
	{
		/// Initialize T16 timer.
		c17setT16(3, (T16CH3_INIT & 0x60)>>5, (T16CH3_INIT & 0x0F), (T16CH3_INIT & 0x10)>>4);

		/// Initialize the interrupt.
		ILVT16_3 = INTERRUPT_LEVEL_T16_3;				/// - Set interrupt level.
	}
#endif

#if defined(C17_MCUSEL_M01) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_589) || \
	defined(C17_MCUSEL_M10)
	/// T16 CH 4 Setting
	if((T16CH4_INIT & 0x80) == 0x80)
	{
		/// Initialize T16 timer.
		c17setT16(4, (T16CH4_INIT & 0x60)>>5, (T16CH4_INIT & 0x0F), (T16CH4_INIT & 0x10)>>4);

		/// Initialize the interrupt.
		ILVT16_4 = INTERRUPT_LEVEL_T16_4;				/// - Set interrupt level.
	}
#endif

#if defined(C17_MCUSEL_589)
	/// T16 CH 5 Setting
	if((T16CH5_INIT & 0x80) == 0x80)
	{
		/// Initialize T16 timer.
		c17setT16(5, (T16CH5_INIT & 0x60)>>5, (T16CH5_INIT & 0x0F), (T16CH5_INIT & 0x10)>>4);

		/// Initialize the interrupt.
		ILVT16_5 = INTERRUPT_LEVEL_T16_5;				/// - Set interrupt level.
	}
#endif
}


/************************************************************************//**
 * @brief   T16 timer set.
 *
 * @param   t16Channel              Timer CH.
 *  @li @c  0 to CH_MAX_COUNT-1
 * @param   t16ClkSrc               Clock Source.
 *  @li @c  C17_T16_CLKSRC_IOSC
 *  @li @c  C17_T16_CLKSRC_OSC1
 *  @li @c  C17_T16_CLKSRC_OSC3
 *  @li @c  C17_T16_CLKSRC_EXT
 * @param   t16ClkDiv               Clock Division
 *  @li @c  C17_T16_CLKDIV_1 to C17_T16_CLKDIV_32768
 * @param   t16Mode                 Mode
 *  @li @c  C17_T16_MODE_ONESHOT    One shot.
 *  @li @c  C17_T16_MODE_REPEAT     Repeat.
 *
 * @retval  none
 ***************************************************************************/
void c17setT16(unsigned short t16Channel, unsigned short t16ClkSrc, unsigned short t16ClkDiv, unsigned short t16Mode)
{
	T16_NCTL_REG	t16_nctl_set;
	T16_NCLK_REG	t16_nclk_set;
	T16_NMOD_REG	t16_nmod_set;

	if(t16Channel >= CH_MAX_COUNT) {
		return;
	}

	/// Stop T16 Ch.N Timer.
	c17stopT16(t16Channel);

	/* T16_NCTL:T16 Ch.N Control Register. */
	{
		t16_nctl_set.reg = 0;
		t16_nctl_set.bit.PRUN = 0;
		t16_nctl_set.bit.PRESET = 0;
		t16_nctl_set.bit.MODEN = 0;					/// - Stop supplying operating clock
		t16_nctl_table[t16Channel]->reg = t16_nctl_set.reg;
	}

	/// Configure the T16 Ch.N operating clock.
	/* T16_NCLK: T16 Ch.N Clock Control Register. */
	{
		t16_nclk_set.reg = 0;
		t16_nclk_set.bit.DBRUN = 0;					/// - No clock supplied in DEBUG mode
		if(t16ClkSrc == C17_T16_CLKSRC_OSC1)
		{
			/**
			 *  Clock source = OSC1,Clock division = C17_T16_CLKDIV_1 to C17_T16_CLKDIV_256
			 */
			if(t16ClkDiv > C17_T16_CLKDIV_256)
			{
				t16ClkDiv = C17_T16_CLKDIV_256;
			}
		}
		t16_nclk_set.bit.CLKDIV = t16ClkDiv;		/// - Clock division ratio selection
		t16_nclk_set.bit.CLKSRC =  t16ClkSrc;		/// - Clock source selection
		t16_nclk_table[t16Channel]->reg =  t16_nclk_set.reg;
	}

	/// Enable T16
	/* T16_NCTL:T16 Ch.N Control Register. */
	{
		t16_nctl_set.reg = 0;
		t16_nctl_set.bit.MODEN = 1;					/// - Start supplying operating clock.
		t16_nctl_table[t16Channel]->reg = t16_nctl_set.reg;
	}

	/// Select operation mode.
	/* T16_NMOD:T16 Ch.N Mode Register */
	{
		t16_nmod_set.reg = 0;
		t16_nmod_set.bit.TRMD = t16Mode;			/// - Set Repeat mode.
		t16_nmod_table[t16Channel]->reg  = 	t16_nmod_set.reg;
	}
}


/************************************************************************//**
 * @brief   T16 timer disable.
 *
 * @param   t16Channel      Timer CH.
 *  @li @c  0 to CH_MAX_COUNT-1
 *
 * @retval  none
 ***************************************************************************/
void c17disableT16(unsigned short t16Channel)
{
	T16_NCTL_REG	t16_nctl_set;

	if(t16Channel >= CH_MAX_COUNT) {
		return;
	}

	/* T16_NCTL:T16 Ch.N Control Register. */
	{
		t16_nctl_set.reg = t16_nctl_table[t16Channel]->reg;
		t16_nctl_set.bit.MODEN = 0;			///-  T16_NCTL.MODEN set 0.
		t16_nctl_table[t16Channel]->reg = t16_nctl_set.reg;
	}
}


/************************************************************************//**
 * @brief   T16 timer start.
 *
 * @param   t16Channel      Timer CH.
 *  @li @c  0 to CH_MAX_COUNT-1
 *
 * @retval  none
 ***************************************************************************/
void c17startT16(unsigned short t16Channel)
{
	T16_NCTL_REG	t16_nctl_set;

	if(t16Channel >= CH_MAX_COUNT) {
		return;
	}

	/* T16_NCTL:T16 Ch.N Control Register. */
	{
		t16_nctl_set.reg = t16_nctl_table[t16Channel]->reg;
		t16_nctl_set.bit.PRUN = 1;				///-  T16_NCTL.PRUN set 1(timer start).
		t16_nctl_table[t16Channel]->reg = t16_nctl_set.reg;
	}
}


/************************************************************************//**
 * @brief   T16 timer stop.
 *
 * @param   t16Channel      Timer CH.
 *  @li @c  0 to CH_MAX_COUNT-1
 *
 * @retval  none
 ***************************************************************************/
void c17stopT16(unsigned short t16Channel)
{
	T16_NCTL_REG	t16_nctl_set;

	if(t16Channel >= CH_MAX_COUNT) {
		return;
	}

	c17disableIntT16(t16Channel);					///-  Interrupt disable

	/* T16_NCTL:T16 Ch.N Control Register. */
	{
		t16_nctl_set.reg = t16_nctl_table[t16Channel]->reg;
		t16_nctl_set.bit.PRUN = 0;			///-  T16_NCTL.PRUN set 0(timer stop).
		t16_nctl_table[t16Channel]->reg = t16_nctl_set.reg;
	}
}


/************************************************************************//**
 * @brief   T16 timer start.
 *
 * @param   t16Channel      Timer CH.
 *  @li @c  0 to CH_MAX_COUNT-1
 *
 * @retval  none
 ***************************************************************************/
void c17enableIntT16(unsigned short t16Channel)
{
	T16_NINTF_REG	t16_nintf_set;
	T16_NINTE_REG	t16_ninte_set;

	if(t16Channel >= CH_MAX_COUNT) {
		return;
	}

	/* T16_NINTF:T16 Ch.N Interrupt Flag Register */
	{
		t16_nintf_set.reg = 0;
		t16_nintf_set.bit.UFIF = 1;
		t16_intf_table[t16Channel]->reg = t16_nintf_set.reg;		///- Clear interrupt flag.
	}

	/*T16_NINTE: T16 Ch.N Interrupt Enable Register */
	{
		t16_ninte_set.reg = 0;
		t16_ninte_set.bit.UFIE = 1;			///- Enable T16 Ch.N underflow interrupts.
		t16_inte_table[t16Channel]->reg = t16_ninte_set.reg;
	}
}


/************************************************************************//**
 * @brief   T16 timer stop.
 *
 * @param   t16Channel      Timer CH.
 *  @li @c  0 to CH_MAX_COUNT-1
 *
 * @retval  none
 ***************************************************************************/
void c17disableIntT16(unsigned short t16Channel)
{
	T16_NINTF_REG	t16_nintf_set;
	T16_NINTE_REG	t16_ninte_set;

	if(t16Channel >= CH_MAX_COUNT) {
		return;
	}

	/* T16_NINTF:T16 Ch.N Interrupt Flag Register */
	{
		t16_nintf_set.reg = 0;
		t16_nintf_set.bit.UFIF = 1;  			///- Clear interrupt flag.
		t16_intf_table[t16Channel]->reg = t16_nintf_set.reg;
	}
	/*T16_NINTE: T16 Ch.N Interrupt Enable Register */
	{
		t16_ninte_set.reg = 0;
		t16_ninte_set.bit.UFIE = 0;				///- Disable T16 Ch.N underflow interrupts.
		t16_inte_table[t16Channel]->reg = t16_ninte_set.reg;
	}
}


/************************************************************************//**
 * @brief   Set T16 timer reload value.
 *
 * @param   t16Channel      Timer CH.
 *  @li @c  0 to CH_MAX_COUNT-1
 * @param   t16Count   Count Data.
 *
 * @retval  none
 ***************************************************************************/
void c17setCountT16(unsigned short t16Channel, unsigned short t16Count)
{
	T16_NCTL_REG	t16_nctl_set;

	if(t16Channel >= CH_MAX_COUNT) {
		return;
	}

	t16_ntr_table[t16Channel]->reg = t16Count;	///- Set the initial value to be preset to the counter.

	/* T16_NCTL:T16 Ch.N Control Register. */
	{
		t16_nctl_set.reg = t16_nctl_table[t16Channel]->reg;
		t16_nctl_set.bit.PRESET = 1;			///- Presets the reload data stored in the T16_NTR register to the counter.
		t16_nctl_table[t16Channel]->reg = t16_nctl_set.reg;
	}
}


/************************************************************************//**
 * @brief   Get Counter Data
 *
 * @param   t16Channel      Timer CH.
 *  @li @c  0 to CH_MAX_COUNT-1
 *
 * @retval  Count Data          The counter value return.
 ***************************************************************************/
unsigned short c17getCountT16(unsigned short t16Channel)
{
	return t16_ntc_table[t16Channel]->reg;
}


/************************************************************************//**
 * @brief   T16 CH.0 Interrupt function.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17intT16Ch0(void)
{
	T16_NINTF_REG	t16_0intf_set;

	/* T16_0INTF  T16 Ch.0  Interrupt Flag Register read & clear */
	{
		t16_0intf_set.reg = T16_0INTF;
		T16_0INTF = t16_0intf_set.reg;
	}

	/// Check interrupt cause occurrence status.
	if(t16_0intf_set.bit.UFIF == 1) {
	   /**
		* @todo add interrupt function of T16 ch0
		*/
		/// Increment the interrupt counter.
		c17t16Ch0IntCount++;
	}
}


/************************************************************************//**
 * @brief   T16 CH.1 Interrupt function.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17intT16Ch1(void)
{
	T16_NINTF_REG	t16_1intf_set;

	/* T16_1INTF  T16 Ch.1  Interrupt Flag Register read & clear */
	{
		t16_1intf_set.reg = T16_1INTF;
		T16_1INTF = t16_1intf_set.reg;
	}

	/// Check interrupt cause occurrence status.
	if(t16_1intf_set.bit.UFIF == 1) {

	   /**
		* @todo add interrupt function of T16 ch1
		*/
	}
}


#if defined(C17_MCUSEL_M01) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M12) || defined(C17_MCUSEL_M13) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13) || \
	defined(C17_MCUSEL_W14) || defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W15) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_589) || \
	defined(C17_MCUSEL_M10) || \
	defined(C17_MCUSEL_M40) || \
	defined(C17_MCUSEL_F63)
/************************************************************************//**
 * @brief   T16 CH.2 Interrupt function.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17intT16Ch2(void)
{
	T16_NINTF_REG	t16_2intf_set;

	/* T16_2INTF  T16 Ch.2  Interrupt Flag Register read & clear */
	{
		t16_2intf_set.reg = T16_2INTF;
		T16_2INTF = t16_2intf_set.reg;
	}

	/// Check interrupt cause occurrence status.
	if (t16_2intf_set.bit.UFIF == 1) {

	   /**
		* @todo add interrupt function of T16 ch2
		*/
	}
}
#endif


#if defined(C17_MCUSEL_M01) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M12) || defined(C17_MCUSEL_M13) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_589) || \
	defined(C17_MCUSEL_M10) || \
	defined(C17_MCUSEL_M40) || \
	defined(C17_MCUSEL_F63)
/************************************************************************//**
 * @brief   T16 CH.3 Interrupt function.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17intT16Ch3(void)
{
	T16_NINTF_REG	t16_3intf_set;

	/* T16_3INTF  T16 Ch.3  Interrupt Flag Register read & clear */
	{
		t16_3intf_set.reg = T16_3INTF;
		T16_3INTF = t16_3intf_set.reg;
	}

	/// Check interrupt cause occurrence status.
	if(t16_3intf_set.bit.UFIF == 1) {
	   /**
		* @todo add interrupt function of T16 ch3
		*/
	}
}
#endif


#if defined(C17_MCUSEL_M01) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_589) || \
	defined(C17_MCUSEL_M10)
/************************************************************************//**
 * @brief   T16 CH.4 Interrupt function.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17intT16Ch4(void)
{
	T16_NINTF_REG	t16_4intf_set;

	/* T16_4INTF  T16 Ch.4  Interrupt Flag Register read & clear */
	{
		t16_4intf_set.reg = T16_4INTF;
		T16_4INTF = t16_4intf_set.reg;
	}

	/// Check interrupt cause occurrence status.
	if(t16_4intf_set.bit.UFIF == 1) {
	   /**
		* @todo add interrupt function of T16 ch4
		*/
	}
}
#endif


#if defined(C17_MCUSEL_589)
/************************************************************************//**
 * @brief   T16 CH.5 Interrupt function.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17intT16Ch5(void)
{
	T16_NINTF_REG	t16_5intf_set;

	/* T16_5INTF  T16 Ch.5  Interrupt Flag Register read & clear */
	{
		t16_5intf_set.reg = T16_5INTF;
		T16_5INTF = t16_5intf_set.reg;
	}

	/// Check interrupt cause occurrence status.
	if(t16_5intf_set.bit.UFIF == 1) {
	   /**
		* @todo add interrupt function of T16 ch5
		*/
	}
}
#endif

#endif

