/************************************************************************//**
 *
 * @file    main.c
 *
 * @brief   This is S1C17F63 sample program.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2018-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Jun. 2018    1.00
 *              - First revision.
 *
 ***************************************************************************/
/************************************************************************//**
 * @main_page   S1C17F63 Sample Program.
 *
 * @section     intro Introduction
 * This is a sample code of S1C17F63.
 *
 * @subsection  --- S1C17F63 ---
 * @subsection  step0   Step  0: CLG.
 * @subsection  step1   Step  1: ADC.
 * @subsection  step2   Step  2: EEPROMC.
 * @subsection  step3   Step  3: EPDC.
 * @subsection  step4   Step  4: I2C.
 * @subsection  step5   Step  5: PORT.
 * @subsection  step6   Step  6: PWG.
 * @subsection  step7   Step  7: RTCLP.
 * @subsection  step8   Step  8: SNDA.
 * @subsection  step9   Step  9: SPIA.
 * @subsection  step10  Step 10: SVD.
 * @subsection  step11  Step 11: T16.
 * @subsection  step12  Step 12: T16B.
 * @subsection  step13  Step 13: TSRVR.
 * @subsection  step14  Step 14: UART.
 * @subsection  step15  Step 15: WDT.
 *
 * @section     install Installation
 * Start the IDE and import the "s1c17f63_sample" project.
 *
 ***************************************************************************/
#include <stdlib.h>
#include <stdio.h>
#include "crt0.h"
#include "c17_misc.h"
#include "c17_init_config.h"
#include <c17_mcu_select.h>
#include "main.h"


/* --- global variable --- */

int main(void);

/************************************************************************//**
 * main function.
 *
 * @return  EXIT_SUCCESS    Success.
 * @return  EXIT_FAILURE    Failed.
 ***************************************************************************/
int main(void)
{
	/* <<< s1c17f63 demonstration start >>> */
	main_clg();

#ifdef C17_PE_ADC
	main_adc12a();
#endif

#ifdef C17_PE_EEPROMC
	main_eepromc();
#endif

#ifdef C17_PE_EPDC
	main_epdc();
#endif

#if defined(C17_PE_I2C_MASTER) || defined( C17_PE_I2C_SLAVE)
	main_i2c();
#endif

#ifdef C17_PE_PORT
	main_port();
#endif

#ifdef C17_PE_PWG
	main_pwg();
#endif

#ifdef C17_PE_RTCLP
	main_rtclp();
#endif

#ifdef C17_PE_SNDA
	main_snda();
#endif

#if defined(C17_PE_SPIA_MASTER) || defined(C17_PE_SPIA_SLAVE)
	main_spia();
#endif

#ifdef C17_PE_SVD
	main_svd3();
#endif

#ifdef C17_PE_T16
	main_t16();
#endif

#ifdef C17_PE_T16B
	main_t16b();
#endif

#ifdef C17_PE_TSRVR
	main_tsrvr();
#endif

#if defined(C17_PE_UART_MASTER) || defined( C17_PE_UART_SLAVE)
	main_uart3();
#endif

#ifdef C17_PE_WDT
	main_wdt2();
#endif

	/* <<< s1c17f63 demonstration finish >>> */

	return EXIT_SUCCESS;

}

