/************************************************************************//**
 *
 * @file    main.c
 *
 * @brief   This is T16 PWM Timer(T16B) Ch.0 sample program for S1C17F63 demonstration.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2018-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Jun. 2018    1.00
 *              - First revision.
 *
 ***************************************************************************/
/************************************************************************//**
 * @mainpage    S1C17F63 T16 PWM Timer(T16B) Ch.0
 *
 * @section     intro Introduction
 * Sample code for start T16 PWM Timer(T16B) Ch.0.
 *
 * @subsection  step1   Initialize and start T16B(Ch.0).
 * @subsection  step2   Set comparator count to 0x2000.
 * @subsection  step3   Start T16B(Ch.0) and PWM output TOUT00(P00).
 * @subsection  step4   Stop the T16B(Ch.0) when counter MAX
 *                      interrupt count becomes ten.
 * @subsection  step5   Get interrupt counter.
 *
 * @section     install Installation
 * Start the IDE and import the "s1c17f63_sample" project.
 *
 ************************************************************************* */
#include <stdlib.h>
#include "c17_init_config.h"
#include "c17_misc.h"
#include "c17_clg.h"
#include "c17_t16b.h"


#ifdef C17_PE_T16B
/* --- global variable --- */

int main_t16b(void);



/************************************************************************//**
 * main function.
 *
 * @brief   Start T16 PWM Timer(T16B) Ch.0.
 *
 * @return  EXIT_SUCCESS    Success.
 ***************************************************************************/
int main_t16b(void)
{
	int i;
	volatile unsigned short count = 0;

	/// This variable is for debugging.
	/// Warning comes out, but there is no problem.
	volatile unsigned short data;

	/// Clock = IOSC
	c17startClgIOSC();
	c17switchClgSystemClockIOSC();
	c17stopClgOSC3();

	/// start OSC3(internal oscillator)
	c17startClgIntOSC3(C17_CLG_OSC3_16MHZ);

	/// the system clock set in OSC3.
	c17switchClgSystemClockOSC3();
	c17stopClgIOSC();


	/* <<< 16-bit PWM Timers(T16B) demonstration start >>> */

	/// Initialize T16B CH.0 timer.
	c17initT16b();

	/// Set max count.
	c17setT16bCh0MaxCount(0x5000);
	/// Set comparator count.
	c17setT16bCh0ComparatorCount(0x2000);


	/// Reset counter(global variable).
	c17resetT16bCh0IntCount();

	/// Start T16B(Ch.0) and PWM output.
	c17startT16b(0);

	///Halt.
	while(count < 10){

		// Set halt mode.
		// Nop is necessary when the main program is not executed after
		// halt is	released, and it diverges to the server blade.
		asm("halt");
		asm("nop");

		/// Get counter MAX interrupt count.
		count = c17getT16bCh0IntMaxCount();
	}

	/// Stop T16B(Ch.0).
	c17stopT16b(0);

	/// Get interrupt counter.
	data = c17getT16bCh0ComparatorCount();
	data = c17getT16bCh0TimerCount();
	data = c17getT16bCh0MaxCount();
	data = c17getT16bCh0IntMaxCount();
	data = c17getT16bCh0IntZeroCount();
	data = c17getT16bCh0IntComparatorCount();
	data = c17getT16bCh0IntCaptureCount();

	for (i = 0; i < T16B_CH0_INT_CAP_DATA_MAX; i++) {
		data = c17getT16bCh0IntCaptureCountData(i);
	}


	/* <<< 16-bit PWM Timers(T16B) demonstration finish >>> */

	return EXIT_SUCCESS;
}
#endif

