/************************************************************************//**
 *
 * @file    pwg_reg.h
 *
 * @brief   Definition of the Power Generator(PWG) Register.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2016-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *          - 01 Nov. 2018    1.10
 *              - Change source code.
 *
 ******************************************************************************/
#ifndef PWG_REG_H__
#define PWG_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

/// PWG VD1 Regulator Control Register
typedef union PWGVD1CTL_REG_TAG {
    unsigned short  reg;
    struct PWGVD1CTL_REG_BIT_TAG {
        /**
         * PWG VD1 Regulator Control Register.
         * .REGMODE[1:0]
         *  These bits control the internal regulator operating mode.
         * +--------------+----------------+
         * | REGMODE[1:0] | Operating mode |
         * +--------------+----------------+
         * |     0x3      |  Economy mode  |
         * +--------------+----------------+
         * |     0x2      |   Normal mode  |
         * +--------------+----------------+
         * |     0x1      |    Reserved    |
         * +--------------+----------------+
         * |     0x0      | Automatic mode |
         * +--------------+----------------+
         */
        unsigned short      REGMODE     : 2;
        unsigned short      reserved_1  :14;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} PWGVD1CTL_REG;

#ifdef __cplusplus
}
#endif

#endif // PWG_REG_H__
