/************************************************************************//**
 *
 * @file    c17_eepromc.h
 *
 * @brief   This is EEPROMC driver header file.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2018-2019. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Jun. 2018    1.00
 *              - First revision.
 *          - 19 Jun. 2019    1.10
 *              - Change source code.
 *
 ***************************************************************************/
#ifndef C17_EEPROMC_H__
#define C17_EEPROMC_H__

#include <c17_mcu_select.h>

/* --- definition --- */
enum
{
	C17_EEPROMC_WAIT_T16_ch0,			///< Wait timer use t16 ch.0
	C17_EEPROMC_WAIT_T16_ch1,			///< Wait timer use t16 ch.1
	C17_EEPROMC_WAIT_T16_ch2,			///< Wait timer use t16 ch.2
	C17_EEPROMC_WAIT_T16_ch3,			///< Wait timer use t16 ch.3
};

enum
{
	C17_EEPROMC_STATE_STDNDBY,			///< Async_State Write standby.
	C17_EEPROMC_STATE_WRITING,			///< Async_State Writing.
	C17_EEPROMC_STATE_COMPLETE			///< Async_State Write completed.
};

enum
{
	C17_EEPROMC_ERROR_VERIFY = 2		///< Verify Error
};

/// EEPROM Address
#define EEPROM_ADDRESS		(0x6000)


/* --- external declaration --- */
extern void c17intEepromc(void)		__attribute__ ((interrupt_handler));

extern void c17initEeprom(void);
extern int c17readEeprom(unsigned char eepromAddress, unsigned char *eepromData);
extern int c17writeEepromSync(unsigned char eepromAddress, unsigned char eepromData);
extern int c17writeEepromAsync(unsigned char eepromAddress, unsigned char eepromData);
extern int c17writeEepromAsyncCheck(unsigned char eepromAddress);

#endif	// C17_EEPROMC_H__

