/************************************************************************//**
 *
 * @file    c17_epdc.h
 *
 * @brief   This is EPDC driver header file.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2018-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Jun. 2018    1.00
 *              - First revision.
 *
 ***************************************************************************/
#ifndef C17_EPDC_H__
#define C17_EPDC_H__

#include <c17_mcu_select.h>

/* --- definition --- */
enum
{
	C17_EPDC_CLKSRC_IOSC,				///< Clock Source = IOSC
	C17_EPDC_CLKSRC_OSC1,				///< Clock Source = OSC1
	C17_EPDC_CLKSRC_OSC3,				///< Clock Source = OSC3
	C17_EPDC_CLKSRC_EXOSC				///< Clock Source = External OSC
};

enum
{
	C17_EPDC_CLKDIV_TIM_128,			///< Clock Division = 1/128
	C17_EPDC_CLKDIV_TIM_256,			///< Clock Division = 1/256
	C17_EPDC_CLKDIV_TIM_512,			///< Clock Division = 1/512
	C17_EPDC_CLKDIV_TIM_1024,			///< Clock Division = 1/1024
	C17_EPDC_CLKDIV_TIM_2048,			///< Clock Division = 1/2048
	C17_EPDC_CLKDIV_TIM_4096,			///< Clock Division = 1/4096
	C17_EPDC_CLKDIV_TIM_8192,			///< Clock Division = 1/8192
	C17_EPDC_CLKDIV_TIM_16384			///< Clock Division = 1/16384
};

enum
{
	C17_EPDC_CLKDIV_DBL_16,				///< Clock Division = 1/16
	C17_EPDC_CLKDIV_DBL_32,				///< Clock Division = 1/32
	C17_EPDC_CLKDIV_DBL_64,				///< Clock Division = 1/64
	C17_EPDC_CLKDIV_DBL_128,			///< Clock Division = 1/128
	C17_EPDC_CLKDIV_DBL_256,			///< Clock Division = 1/256
};

enum
{
	C17_EPDC_CLKDIV_BST_16,				///< Clock Division = 1/16
	C17_EPDC_CLKDIV_BST_32,				///< Clock Division = 1/32
	C17_EPDC_CLKDIV_BST_64,				///< Clock Division = 1/64
	C17_EPDC_CLKDIV_BST_128,			///< Clock Division = 1/128
	C17_EPDC_CLKDIV_BST_256,			///< Clock Division = 1/256
};

enum
{
	C17_EPDC_CLKDIV_OSC1_1,				///< Clock Division = 1/1
	C17_EPDC_CLKDIV_OSC1_2,				///< Clock Division = 1/2
	C17_EPDC_CLKDIV_OSC1_4,				///< Clock Division = 1/4
	C17_EPDC_CLKDIV_OSC1_8,				///< Clock Division = 1/8
	C17_EPDC_CLKDIV_OSC1_16,			///< Clock Division = 1/16
	C17_EPDC_CLKDIV_OSC1_32,			///< Clock Division = 1/32
	C17_EPDC_CLKDIV_OSC1_64,			///< Clock Division = 1/64
	C17_EPDC_CLKDIV_OSC1_128			///< Clock Division = 1/128
};

enum
{
	C17_EPDC_DSPMD_NORMAL,				///< Display Mode = Normal
	C17_EPDC_DSPMD_REV,					///< Display Mode = Reverse
	C17_EPDC_DSPMD_WHITE,				///< Display Mode = All white
	C17_EPDC_DSPMD_BLACK				///< Display Mode = All black
};

enum
{
	C17_EPDC_CNT_WAVE,					///< Controller = Wave mode
	C17_EPDC_CNT_DIRECT					///< Controller = Direct mode
};

enum
{
	C17_PLN_SEGHZ_NORMAL,				///< Segment/back plane Hi-Z control = Normal
	C17_PLN_SEGHZ_HIZ					///< Segment/back plane Hi-Z control = Hi_z
};

enum
{
	C17_PLN_TPHZ_NORMAL,				///< Top plane Hi-Z control = Normal
	C17_PLN_TPHZ_HIZ					///< Top plane Hi-Z control control = Hi_z
};

enum
{
	C17_PLN_TP_LOW,						///< Top plane control data = Low
	C17_PLN_TP_HIGH						///< Top plane control data = High
};

enum
{
	C17_PLN_BP_LOW,						///< Back plane control data = Low
	C17_PLN_BP_HIGH						///< Back plane control data = High
};

enum
{
	C17_EPDC_SEGDATA_W_L,				///< Segment display data = White (wave mode)/Low level (direct mode)
	C17_EPDC_SEGDATA_B_H					///< Segment display data = Black (wave mode)/High level (direct mode)
};

#define	EPDC_WAIT_OSC1_CLK		32768			///< OSC1 clock(32.768kHz)
#define	EPDC_WAIT_IOSC_CLK		700000			///< IOSC clock(700kHz)
#define	EPDC_WAIT_OSC3_CLK		16000000		///< OSC3 clock(16.0MHz)

// Display Memory Address.
#define	EPDC_SEGDATA_TOP_ADDR	(0x5522)		///< EPDC Segment Data Register 0 address.
#define	EPDC_SEGDATA0_ADDR		(0x0)			///< EPDC Segment Data Register 1 address.
#define	EPDC_SEGDATA1_ADDR		(0x2)			///< EPDC Segment Data Register 1 address.
#define	EPDC_SEGDATA2_ADDR		(0x4)			///< EPDC Segment Data Register 2 address.
#define	EPDC_SEGDATA_SIZE		(0x3)			///< The segment data size.
#define	EPDC_WAVE_TOP_ADDR		(0x5540)		///< EPDC Waveform Timing Set 0 Registers address.
#define	EPDC_WAVE0_ADDR			(0x0)			///< EPDC Waveform Timing Set 0 Registers address.
#define	EPDC_WAVE1_ADDR			(0x2)			///< EPDC Waveform Timing Set 1 Registers address.
#define	EPDC_WAVE2_ADDR			(0x4)			///< EPDC Waveform Timing Set 2 Registers address.
#define	EPDC_WAVE3_ADDR			(0x6)			///< EPDC Waveform Timing Set 3 Registers address.
#define	EPDC_WAVE4_ADDR			(0x8)			///< EPDC Waveform Timing Set 4 Registers address.
#define	EPDC_WAVE5_ADDR			(0xA)			///< EPDC Waveform Timing Set 5 Registers address.
#define	EPDC_WAVE6_ADDR			(0xC)			///< EPDC Waveform Timing Set 6 Registers address.
#define	EPDC_WAVE7_ADDR			(0xE)			///< EPDC Waveform Timing Set 7 Registers address.
#define	EPDC_WAVE8_ADDR			(0x10)			///< EPDC Waveform Timing Set 8 Registers address.
#define	EPDC_WAVE9_ADDR			(0x12)			///< EPDC Waveform Timing Set 9 Registers address.
#define	EPDC_WAVE10_ADDR		(0x14)			///< EPDC Waveform Timing Set 10 Registers address.
#define	EPDC_WAVE11_ADDR		(0x16)			///< EPDC Waveform Timing Set 11 Registers address.
#define	EPDC_WAVE12_ADDR		(0x18)			///< EPDC Waveform Timing Set 12 Registers address.
#define	EPDC_WAVE13_ADDR		(0x1A)			///< EPDC Waveform Timing Set 13 Registers address.
#define	EPDC_WAVE14_ADDR		(0x1C)			///< EPDC Waveform Timing Set 14 Registers address.
#define	EPDC_WAVE15_ADDR		(0x1E)			///< EPDC Waveform Timing Set 15 Registers address.
#define	EPDC_WAVE16_ADDR		(0x20)			///< EPDC Waveform Timing Set 16 Registers address.
#define	EPDC_WAVE17_ADDR		(0x22)			///< EPDC Waveform Timing Set 17 Registers address.
#define	EPDC_WAVE18_ADDR		(0x24)			///< EPDC Waveform Timing Set 18 Registers address.
#define	EPDC_WAVE19_ADDR		(0x26)			///< EPDC Waveform Timing Set 19 Registers address.
#define	EPDC_WAVE20_ADDR		(0x28)			///< EPDC Waveform Timing Set 20 Registers address.
#define	EPDC_WAVE21_ADDR		(0x2A)			///< EPDC Waveform Timing Set 21 Registers address.
#define	EPDC_WAVE22_ADDR		(0x2C)			///< EPDC Waveform Timing Set 22 Registers address.
#define	EPDC_WAVE23_ADDR		(0x2E)			///< EPDC Waveform Timing Set 23 Registers address.
#define	EPDC_WAVE24_ADDR		(0x30)			///< EPDC Waveform Timing Set 24 Registers address.
#define	EPDC_WAVE25_ADDR		(0x32)			///< EPDC Waveform Timing Set 25 Registers address.
#define	EPDC_WAVE26_ADDR		(0x34)			///< EPDC Waveform Timing Set 26 Registers address.
#define	EPDC_WAVE27_ADDR		(0x36)			///< EPDC Waveform Timing Set 27 Registers address.
#define	EPDC_WAVE28_ADDR		(0x38)			///< EPDC Waveform Timing Set 28 Registers address.
#define	EPDC_WAVE29_ADDR		(0x3A)			///< EPDC Waveform Timing Set 29 Registers address.
#define	EPDC_WAVE30_ADDR		(0x3C)			///< EPDC Waveform Timing Set 30 Registers address.
#define	EPDC_WAVE31_ADDR		(0x3E)			///< EPDC Waveform Timing Set 31 Registers address.
#define	EPDC_WAVE_SIZE			(0x20)				///< The Waveform Timing Set data size.


/* --- external declaration --- */
extern void c17intEpdc(void)	__attribute__ ((interrupt_handler));

extern void c17initEpdc(void);
extern void c17enableIntEpdc(void);
extern void c17disableIntEpdc(void);
extern void c17enableEpdcModule(void);
extern void c17disableEpdcModule(void);
extern void c17setEpdcOperatingMode(unsigned char mode);
extern void c17setEpdcDisplayMode(unsigned char mode);
extern unsigned char c17getEpdcDisplayMode(void);
extern void c17setEpdcTopBackPlane(unsigned short seghz,  unsigned short tphz, unsigned short tp, unsigned short bp);
extern void c17setEpdcSegData(unsigned short addr, unsigned short data);
extern unsigned short c17getEpdcSegData(unsigned short addr);
extern void c17setEpdcCheckPattern_100(void);
extern void c17setEpdcCheckPattern_000(void);
extern void c17setEpdcWaveform(unsigned short addr, unsigned short data);
extern unsigned short c17getEpdcWaveform(unsigned short addr);
extern void c17startEpdc(void);
extern void c17setEpdc(unsigned short epdTClkSrc, unsigned short epdTClkDiv);
extern void c17setEpdcPinAssignmentSelect(unsigned char pinpos);

#endif // C17_EPDC_H__

