/************************************************************************//**
 *
 * @file    c17_port.h
 *
 * @brief   This is port driver header file.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2018-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Jun. 2018    1.00
 *              - First revision.
 *
 ***************************************************************************/
#ifndef C17_PORT_H__
#define C17_PORT_H__

#include <c17_mcu_select.h>

/* --- definition --- */
enum
{
	C17_PORT_DIR_INPUT , 						///< Port Direction INPUT
	C17_PORT_DIR_OUTPUT 						///< Port Direction OUTPUT
};

enum
{
	C17_PORT_PULL_DISABLE,						///< Port PULL UP/PULL DOWN Control Disable
	C17_PORT_PULL_UP,							///< Port PULL UP
	C17_PORT_PULL_DOWN							///< Port PULL DOWN
};

enum
{
	C17_PORT_INT_EDGE_RISING,					///< Input interrupt signal edge:Rising edge.
	C17_PORT_INT_EDGE_FALLING					///< Input interrupt signal edge:Falling edge.
};

/* --- external declaration --- */
extern void c17intPortInput(void)	__attribute__ ((interrupt_handler));

extern void c17initPort(void);

extern void c17enableIntP0x(unsigned short portNo, unsigned short portIntEdge);
extern void c17enableIntP1x(unsigned short portNo, unsigned short portIntEdge);

extern void c17disableIntP0x(unsigned short portNo);
extern void c17disableIntP1x(unsigned short portNo);

extern unsigned char c17getOutputP0xByte(void);
extern unsigned char c17getOutputP1xByte(void);
extern unsigned char c17getOutputPDxByte(void);

extern unsigned char c17getOutputP0x(unsigned short portNo);
extern unsigned char c17getOutputP1x(unsigned short portNo);
extern unsigned char c17getOutputPDx(unsigned short portNo);

extern void c17setOutputP0xByte(unsigned char portData);
extern void c17setOutputP1xByte(unsigned char portData);
extern void c17setOutputPDxByte(unsigned char portData);

extern void c17setOutputP0x(unsigned short portNo, unsigned short portData);
extern void c17setOutputP1x(unsigned short portNo, unsigned short portData);
extern void c17setOutputPDx(unsigned short portNo, unsigned short portData);

extern unsigned char c17getInputP0xByte(void);
extern unsigned char c17getInputP1xByte(void);
extern unsigned char c17getInputPDxByte(void);

extern unsigned char c17getInputP0x(unsigned short portNo);
extern unsigned char c17getInputP1x(unsigned short portNo);
extern unsigned char c17getInputPDx(unsigned short portNo);

extern void c17setDirectionP0x(unsigned short portNo, unsigned short portDir, unsigned short portChatta, unsigned short portPull);
extern void c17setDirectionP1x(unsigned short portNo, unsigned short portDir, unsigned short portChatta, unsigned short portPull);
extern void c17setDirectionPDx(unsigned short portNo, unsigned short portDir, unsigned short portChatta, unsigned short portPull);

#endif	//C17_PORT_H__

