/************************************************************************//**
 *
 * @file    c17_rtclp.h
 *
 * @brief   This is RTCLP driver header.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2018-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Jun. 2018    1.00
 *              - First revision.
 *
 ***************************************************************************/
#ifndef C17_RTCLP_H__
#define C17_RTCLP_H__

#include <c17_mcu_select.h>

/* --- definition --- */
enum
{
	C17_RTCLP_12H,						///< Hour counter - 12H mode.
	C17_RTCLP_24H						///< Hour counter - 24H mode.
};

enum
{
	C17_RTCLP_AM,						///< Mode - A.M.
	C17_RTCLP_PM						///< Mode - P.M.
};

enum
{
	C17_RTCLP_SUN,						///< Day of the week - Sunday.
	C17_RTCLP_MON,						///< Day of the week - Monday.
	C17_RTCLP_TUE,						///< Day of the week - Tuesday.
	C17_RTCLP_WED,						///< Day of the week - Wednesday.
	C17_RTCLP_THU,						///< Day of the week - Thursday.
	C17_RTCLP_FRI,						///< Day of the week - Friday.
	C17_RTCLP_SAT						///< Day of the week - Saturday.
};

enum
{
	C17_RTCLP_DCNT_MODE_REPEAT,			///< Repeat mode.
	C17_RTCLP_DCNT_MODE_ONESHOT			///< One shot mode.
};

#define	C17_RTCLP_SVL_NEGATE	0		///< Selection of SPI slave device - negate.
#define	C17_RTCLP_SVL_0			1		///< Selection of SPI slave device - 0.
#define	C17_RTCLP_SVL_1			2		///< Selection of SPI slave device - 1.
#define	C17_RTCLP_SVL_2			4		///< Selection of SPI slave device - 2.

/* --- Struct   ---*/
typedef struct st_rtclp_bcd {
	unsigned char year;
	unsigned char month;
	unsigned char day;
	unsigned char hour;
	unsigned char minute;
	unsigned char second;
	unsigned char week;
	unsigned char ampm;
} ST_RTCLP_BCD;

/* --- external declaration --- */
extern void c17intRtclp(void)	__attribute__ ((interrupt_handler));

extern int c17initRtclp(void);
extern void c17enableMcu(void);
extern void c17disableMcu(void);
extern void c17startRtclp(void);
extern void c17stopRtclp(void);
extern void c17intRtclp(void);
extern void c17setRtclpDate(ST_RTCLP_BCD* rtcBcd);
extern void c17getRtclpDate(ST_RTCLP_BCD* rtcBcd);
extern void c17setRtclpAlarm(ST_RTCLP_BCD* rtcBcd);
extern void c17enableIntRtclp(void);
extern void c17disableIntRtclp(void);
extern int c17setRtclpMode(unsigned short rtclpMode);
extern unsigned short c17getRtclpMode(void);
extern void c17startSw(void);
extern void c17stopSw(void);
extern void c17enableIntSW(void);
extern void c17disableIntSW(void);
extern unsigned short c17readSwCount(void);

extern void c17setRtclpDcnt(unsigned short mode, unsigned short reload);
extern void c17startRtclpDcnt(void);
extern void c17stopRtclpDcnt(void);
extern void c17enableIntRtclpDcnt(void);
extern void c17disableIntRtclpDcnt(void);

extern void c17stopMcu(void);


#endif	//C17_RTCLP_H__

