/************************************************************************//**
 *
 * @file    main.c
 *
 * @brief   This is ADC12A sample program for S1C17F63 demonstration.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2018-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Jun. 2018    1.00
 *              - First revision.
 *
 ***************************************************************************/
/************************************************************************//**
 * @main page   S1C17F63 12bit AD Converter(ADC12A)
 *
 * @section     intro Introduction
 * It is a sample code for analog devices - A/D converter.
 *
 * @subsection  step0   Interrupt every 1sec and check ADC convert value. 10count.
 *              step1   Interrupt every check ADC convert value. 10count.
 *
 * @section     install Installation
 * Start the IDE and import the "s1c17f63_sample" project.
 *
 ***************************************************************************/
#include <stdlib.h>
#include "c17_init_config.h"
#include "c17_misc.h"
#include "c17_adc12a.h"
#include "c17_t16.h"

#ifdef C17_PE_ADC

extern volatile unsigned char c17adcIntCount;

/* --- function declaration --- */

int main_adc12a(void);

/***************************************************************************
 * main function.
 *
 * @brief   1, initialize A/D Converter.
 *
 *          2, initialize T16 timer.
 *
 *          3, set the counter of the T16 timer.
 *
 *          4, initialize and start T16 timer.
 *
 *          5, start A/D Converter.
 *
 *          6, it waits until completion of a conversion interrupt occurs 10 times.
 *
 *          7, stop A/D Converter.
 *
 *          8, stop T16 timer.
 *
 * @return  EXIT_SUCCESS    Success.
 ************************************************************************* */
int main_adc12a(void)
{

	/* <<< 12-bit A/D Converter demonstration start >>> */

	///Initialize ADC12A.(T16 Trigger)
	c17initAdc();

	/// Clear Interruption counter.
	c17adcIntCount = 0;

	/**
	 * Clock Source=IOSC(700KHz)
	 * Clock Division = 1/32
	 * Ft = 1sec
	 * TR = 1[sec] * f(700KHz/32) -1 = 21874
	 */
	/// Initialize T16 CH.2 timer.
	c17setT16(2, C17_T16_CLKSRC_IOSC, C17_T16_CLKDIV_32, C17_T16_MODE_REPEAT);

	/// Set Reload Value T16 CH.2
	c17setCountT16(2, 21874);

	/// Start T16 CH.2 timer.
	c17startT16(2);

	/// ADC12A Interrupt Enable
	c17enableIntAdc();

	///Start ADC12A.
	c17startAdc();


	///Halt.  Interrupt every 1sec, start ADC convert.
	while(c17adcIntCount < 10){

		// Set halt mode.
		// Nop is necessary when the main program is not executed after
		// halt is	released, and it diverges to the server blade.
		asm ("halt");
		asm ("nop");

	}


	///ADC12A Interrupt Disable
	c17disableIntAdc();

	///Stop ADC12A.
	c17stopAdc();

	/// Stop T16 CH.2 timer.
	c17stopT16(2);

	/// Disable T16 CH.2 timer.
	c17disableT16(2);

	/* <<< 12-bit A/D Converter demonstration finish >>> */

	return EXIT_SUCCESS;

}
#endif

